@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,44 +23,59 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/privileges.h>
 #include <client/logic.h>
 #include <filter/roles.h>
+#include <filter/indonesian.h>
 
 
 // Returns true if the $user has read access to the $bible.
 // If no $user is given, it takes the currently logged-in user.
-bool access_bible_read (void * webserver_request, const string & bible, string user)
+bool AccessBible::Read (void * webserver_request, const string & bible, string user)
 {
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+
   // Client: User has access to all Bibles.
 #ifdef HAVE_CLIENT
   return true;
 #endif
 
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
-  int level = 0;
+  // Get the level, that is the role, of the given user.
+  int role_level { 0 };
   if (user.empty ()) {
     // Current user.
     user = request->session_logic ()->currentUser ();
-    level = request->session_logic ()->currentLevel ();
+    role_level = request->session_logic ()->currentLevel ();
   } else {
     // Take level belonging to user.
-    level = request->database_users ()->get_level (user);
+    role_level = request->database_users ()->get_level (user);
+  }
+
+  // Indonesian Cloud Free.
+  if (config_logic_indonesian_cloud_free ()) {
+    // A free guest account has a role of "Consultant".
+    if (role_level == Filter_Roles::consultant()) {
+      // This level/role has access to:
+      // 1. AlkitabKita / Everyone's Translation.
+      if (bible == filter_indonesian_alkitabkita_ourtranslation_name ()) return true;
+      // 2. Terjemahanku <user> (My Translation <user>).
+      else if (bible == filter_indonesian_terjemahanku_mytranslation_name (user)) return true;
+      // If the Bible is none of the above, the free guest account does not have access to it.
+      else return false;
+    }
   }
 
   // Managers and higher have read access.
-  if (level >= Filter_Roles::manager ()) {
+  if (role_level >= Filter_Roles::manager ()) {
     return true;
   }
 
   // Read privileges for the user.
-  bool read, write;
-  Database_Privileges::getBible (user, bible, read, write);
+  auto [ read, write ] = Database_Privileges::getBible (user, bible);
   if (read) {
     return true;
   }
 
   // No Bibles assigned: Consultant can view any Bible.
-  if (level >= Filter_Roles::consultant ()) {
-    int privileges_count = Database_Privileges::getBibleBookCount ();
-    if (privileges_count == 0) {
+  if (role_level >= Filter_Roles::consultant ()) {
+    if (int privileges_count = Database_Privileges::getBibleBookCount (); privileges_count == 0) {
       return true;
     }
   }
@@ -71,7 +86,7 @@ bool access_bible_read (void * webserver_request, const string & bible, string u
 
 
 // Returns true if the user has write access to the $bible.
-bool access_bible_write (void * webserver_request, const string & bible, string user)
+bool AccessBible::Write (void * webserver_request, const string & bible, string user)
 {
 #ifdef HAVE_CLIENT
   // Client: When not yet connected to the Cloud, the user has access to all Bibles.
@@ -81,9 +96,13 @@ bool access_bible_write (void * webserver_request, const string & bible, string
     return true;
   }
 #endif
-  
+  // Indonesian Cloud Free: Access all Bibles.
+  if (config_logic_indonesian_cloud_free ()) {
+    return true;
+  }
+
   int level = 0;
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   if (user.empty ()) {
     user = request->session_logic ()->currentUser ();
     level = request->session_logic ()->currentLevel ();
@@ -99,16 +118,14 @@ bool access_bible_write (void * webserver_request, const string & bible, string
   }
   
   // Read the privileges for the user.
-  bool read, write;
-  Database_Privileges::getBible (user, bible, read, write);
+  auto [ read, write ] = Database_Privileges::getBible (user, bible);
   if (write) {
     return true;
   }
   
   // No Bibles assigned: Translator can write to any bible.
   if (level >= Filter_Roles::translator ()) {
-    int privileges_count = Database_Privileges::getBibleBookCount ();
-    if (privileges_count == 0) {
+    if (int privileges_count = Database_Privileges::getBibleBookCount (); privileges_count == 0) {
       return true;
     }
   }
@@ -122,7 +139,7 @@ bool access_bible_write (void * webserver_request, const string & bible, string
 // If no user is given, it takes the currently logged-in user.
 // If the user has read-only access to even one book of the $bible,
 // then the user is considered not to have write access to the entire $bible.
-bool access_bible_book_write (void * webserver_request, string user, const string & bible, int book)
+bool AccessBible::BookWrite (void * webserver_request, string user, const string & bible, int book)
 {
 #ifdef HAVE_CLIENT
   // Client: When not yet connected to the Cloud, the user has access to the book.
@@ -133,8 +150,9 @@ bool access_bible_book_write (void * webserver_request, string user, const strin
   }
 #endif
 
+  // Get the user level (role).
   int level = 0;
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   if (user.empty ()) {
     user = request->session_logic ()->currentUser ();
     level = request->session_logic ()->currentLevel ();
@@ -144,6 +162,19 @@ bool access_bible_book_write (void * webserver_request, string user, const strin
     level = request->database_users ()->get_level (user);
   }
 
+  // Indonesian Cloud Free.
+  // The free guest account has a role of Consultant.
+  // The consultant has write access to his/her own Bible.
+  // The consultant has read-access to the "AlkitabKita" Bible.
+  if (config_logic_indonesian_cloud_free ()) {
+    if (level == Filter_Roles::consultant()) {
+      if (bible == filter_indonesian_alkitabkita_ourtranslation_name()) {
+        return false;
+      }
+    }
+    return true;
+  }
+
   // Managers and higher always have write access.
   if (level >= Filter_Roles::manager ()) {
     return true;
@@ -158,8 +189,7 @@ bool access_bible_book_write (void * webserver_request, string user, const strin
 
   // No Bibles assigned: Translator can write to any bible.
   if (level >= Filter_Roles::translator ()) {
-    int privileges_count = Database_Privileges::getBibleBookCount ();
-    if (privileges_count == 0) {
+    if (int privileges_count = Database_Privileges::getBibleBookCount (); privileges_count == 0) {
       return true;
     }
   }
@@ -171,13 +201,13 @@ bool access_bible_book_write (void * webserver_request, string user, const strin
 
 // Returns an array of Bibles the user has read access to.
 // If no user is given, it takes the currently logged-in user.
-vector <string> access_bible_bibles (void * webserver_request, string user)
+vector <string> AccessBible::Bibles (void * webserver_request, string user)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   vector <string> allbibles = request->database_bibles ()->getBibles ();
   vector <string> bibles;
   for (auto & bible : allbibles) {
-    if (access_bible_read (webserver_request, bible, user)) {
+    if (AccessBible::Read (webserver_request, bible, user)) {
       bibles.push_back (bible);
     }
   }
@@ -188,13 +218,13 @@ vector <string> access_bible_bibles (void * webserver_request, string user)
 // This function clamps bible.
 // It returns the $bible if the currently logged-in user has access to it.
 // Else it returns another accessible bible or nothing.
-string access_bible_clamp (void * webserver_request, string bible)
+string AccessBible::Clamp (void * webserver_request, string bible)
 {
-  if (!access_bible_read (webserver_request, bible)) {
-    bible = "";
-    vector <string> bibles = access_bible_bibles (webserver_request);
+  if (!AccessBible::Read (webserver_request, bible)) {
+    bible = string();
+    vector <string> bibles = AccessBible::Bibles (webserver_request);
     if (!bibles.empty ()) bible = bibles [0];
-    Webserver_Request * request = (Webserver_Request *) webserver_request;
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
     request->database_config_user ()->setBible (bible);
   }
   return bible;
@@ -203,14 +233,30 @@ string access_bible_clamp (void * webserver_request, string bible)
 
 // This function checks whether the user in the $webserver_request
 // has $read or $write access to one or more Bibles.
-void access_a_bible (void * webserver_request, bool & read, bool & write)
+// It returns a tuple <read, write>.
+tuple<bool, bool> AccessBible::Any (void * webserver_request)
 {
-  read = false;
-  write = false;
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  bool read = false;
+  bool write = false;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   vector <string> bibles = request->database_bibles ()->getBibles ();
   for (auto & bible : bibles) {
-    if (access_bible_read (webserver_request, bible)) read = true;
-    if (access_bible_write (webserver_request, bible)) write = true;
+    if (AccessBible::Read (webserver_request, bible)) read = true;
+    if (AccessBible::Write (webserver_request, bible)) write = true;
   }
+  if (config_logic_indonesian_cloud_free ()) {
+    if (int level = request->session_logic ()->currentLevel ();
+        level >= Filter_Roles::consultant())
+    {
+      read = true;
+      write = true;
+    } else {
+      read = false;
+      write = false;
+    }
+  }
+  // The results consists of <read, write>.
+  return make_tuple(read, write);
 }
+
+
