@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,17 +17,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_ASSETS_EXTERNAL_H
-#define INCLUDED_ASSETS_EXTERNAL_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 string assets_external_url ();
 string assets_external (void * webserver_request);
 
 string assets_external_logic_link_addon ();
-
-
-#endif
