@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <assets/page.h>
 #include <filter/roles.h>
 #include <filter/string.h>
+#include <filter/url.h>
 #include <webserver/request.h>
 #include <database/versifications.h>
 #include <database/books.h>
@@ -44,6 +45,10 @@
 #include <tasks/logic.h>
 #include <system/index.h>
 #include <rss/logic.h>
+#include <pugixml/pugixml.hpp>
+
+
+using namespace pugi;
 
 
 string bible_settings_url ()
@@ -60,7 +65,7 @@ bool bible_settings_acl (void * webserver_request)
 
 string bible_settings (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   string page;
   Assets_Header header = Assets_Header (translate("Bible"), webserver_request);
@@ -75,12 +80,14 @@ string bible_settings (void * webserver_request)
 
   
   // The Bible.
-  string bible = access_bible_clamp (request, request->query["bible"]);
+  string bible = request->query["bible"];
+  if (bible.empty()) bible = request->post ["val1"];
+  bible = AccessBible::Clamp (request, bible);
   view.set_variable ("bible", escape_special_xml_characters (bible));
 
   
   // Whether the user has write access to this Bible.
-  bool write_access = access_bible_write (request, bible);
+  bool write_access = AccessBible::Write (request, bible);
   if (write_access) view.enable_zone ("write_access");
 
   
@@ -110,27 +117,6 @@ string bible_settings (void * webserver_request)
   view.set_variable ("versification", versification);
 
   
-  // Verse mapping.
-  if (request->query.count ("mapping")) {
-    string mapping = request->query["mapping"];
-    if (mapping == "") {
-      Dialog_List dialog_list = Dialog_List ("settings", translate("Would you like to change the verse mapping?"), translate ("A verse mapping can be used to match verses for parallel Bible display. Please make your choice below."), "");
-      dialog_list.add_query ("bible", bible);
-      Database_Mappings database_mappings;
-      vector <string> mapping_names = database_mappings.names ();
-      for (auto & mapping_name : mapping_names) {
-        dialog_list.add_row (mapping_name, "mapping", mapping_name);
-      }
-      page += dialog_list.run ();
-      return page;
-    } else {
-      if (write_access) Database_Config_Bible::setVerseMapping (bible, mapping);
-    }
-  }
-  string mapping = Database_Config_Bible::getVerseMapping (bible);
-  view.set_variable ("mapping", mapping);
-
-  
   // Book creation.
   if (request->query.count ("createbook")) {
     string createbook = request->query["createbook"];
@@ -200,17 +186,27 @@ string bible_settings (void * webserver_request)
 
   
   // Available books.
-  string bookblock;
+  xml_document book_document;
   vector <int> book_ids = filter_passage_get_ordered_books (bible);
   for (auto & book: book_ids) {
     string book_name = Database_Books::getEnglishFromId (book);
     book_name = translate(book_name);
-    if (manager_level) bookblock.append ("<a href=\"book?bible=" + bible + "&book=" + convert_to_string (book) + "\">");
-    bookblock.append (book_name);
-    if (manager_level) bookblock.append ("</a>");
-    bookblock.append ("\n");
+    xml_node a_or_span_node;
+    if (manager_level) {
+      a_or_span_node = book_document.append_child("a");
+      string href = filter_url_build_http_query ("book", "bible", bible);
+      href = filter_url_build_http_query (href, "book", convert_to_string (book));
+      a_or_span_node.append_attribute("href") = href.c_str();
+    } else {
+      a_or_span_node = book_document.append_child("span");
+    }
+    a_or_span_node.text().set(book_name.c_str());
+    xml_node space_node = book_document.append_child("span");
+    space_node.text().set(" ");
   }
-  view.set_variable ("bookblock", bookblock);
+  stringstream bookblock2;
+  book_document.print (bookblock2, "", format_raw);
+  view.set_variable ("bookblock", bookblock2.str());
   view.set_variable ("book_count", convert_to_string ((int)book_ids.size()));
 
 
@@ -221,6 +217,7 @@ string bible_settings (void * webserver_request)
   view.set_variable ("public", get_checkbox_status (Database_Config_Bible::getPublicFeedbackEnabled (bible)));
 
   
+ 
   // RSS feed.
 #ifdef HAVE_CLOUD
   if (checkbox == "rss") {
@@ -233,16 +230,16 @@ string bible_settings (void * webserver_request)
 #endif
 
   
-  // Stylesheet.
-  if (request->query.count ("stylesheet")) {
-    string stylesheet = request->query["stylesheet"];
-    if (stylesheet == "") {
-      Dialog_List dialog_list = Dialog_List ("settings", translate("Would you like to change the stylesheet?"), translate ("A stylesheet affects how the Bible text in the editor looks.") + " " + translate ("Please make your choice below."), "");
+  // Stylesheet for editing.
+  if (request->query.count ("stylesheetediting")) {
+    string stylesheet = request->query["stylesheetediting"];
+    if (stylesheet.empty()) {
+      Dialog_List dialog_list = Dialog_List ("settings", translate("Would you like to change the stylesheet for editing?"), translate ("The stylesheet affects how the Bible text in the editor looks.") + " " + translate ("Please make your choice below."), "");
       dialog_list.add_query ("bible", bible);
       Database_Styles database_styles = Database_Styles();
       vector <string> sheets = database_styles.getSheets();
       for (auto & name : sheets) {
-        dialog_list.add_row (name, "stylesheet", name);
+        dialog_list.add_row (name, "stylesheetediting", name);
       }
       page += dialog_list.run ();
       return page;
@@ -251,8 +248,45 @@ string bible_settings (void * webserver_request)
     }
   }
   string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
-  view.set_variable ("stylesheet", stylesheet);
+  view.set_variable ("stylesheetediting", stylesheet);
+
   
+  // Stylesheet for export.
+  if (request->query.count ("stylesheetexport")) {
+    string stylesheet = request->query["stylesheetexport"];
+    if (stylesheet.empty()) {
+      Dialog_List dialog_list = Dialog_List ("settings", translate("Would you like to change the stylesheet for export?"), translate ("The stylesheet affects how the Bible text looks when exported.") + " " + translate ("Please make your choice below."), "");
+      dialog_list.add_query ("bible", bible);
+      Database_Styles database_styles = Database_Styles();
+      vector <string> sheets = database_styles.getSheets();
+      for (auto & name : sheets) {
+        dialog_list.add_row (name, "stylesheetexport", name);
+      }
+      page += dialog_list.run ();
+      return page;
+    } else {
+      if (write_access) Database_Config_Bible::setExportStylesheet (bible, stylesheet);
+    }
+  }
+  stylesheet = Database_Config_Bible::getExportStylesheet (bible);
+  view.set_variable ("stylesheetexport", stylesheet);
+  
+  
+  // Automatic daily checks on text.
+#ifdef HAVE_CLOUD
+  if (checkbox == "checks") {
+    if (write_access) {
+      Database_Config_Bible::setDailyChecksEnabled (bible, checked);
+      if (!checked) {
+        // If checking is switched off, also remove any existing checking results for this Bible.
+        Database_Check database_check;
+        database_check.truncateOutput(bible);
+      }
+    }
+  }
+  view.set_variable ("checks", get_checkbox_status (Database_Config_Bible::getDailyChecksEnabled (bible)));
+#endif
+
   
   view.set_variable ("systemindex", system_index_url());
   view.set_variable ("success_message", success_message);
