@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CHECK_HEADERS_H
-#define INCLUDED_CHECK_HEADERS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Checks_Headers
 {
 public:
@@ -32,6 +29,3 @@ public:
                                   string centermarks, string endmarks);
 private:
 };
-
-
-#endif
