@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CHECK_PAIRS_H
-#define INCLUDED_CHECK_PAIRS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Checks_Pairs
 {
 public:
@@ -34,6 +31,3 @@ public:
 private:
   static string match (const string & character, const vector <pair <string, string> > & pairs);
 };
-
-
-#endif
