@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,8 @@
  */
 
 
-#ifndef INCLUDED_CHECKS_RUN_H
-#define INCLUDED_CHECKS_RUN_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 void checks_run (string bible);
-
-
-#endif
