@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -99,8 +99,8 @@ void Checks_Sentences::check (map <int, string> texts)
       fullText += " ";
     }
     // Split the UTF-8 text into characters and add them to the arrays of verse_numbers / characters.
-    int count = unicode_string_length (text);
-    for (int i = 0; i < count; i++) {
+    size_t count = unicode_string_length (text);
+    for (size_t i = 0; i < count; i++) {
       character = unicode_string_substr (text, i, 1);
       // Skip characters to be disregarded.
       if (in_array (character, disregards)) continue;
@@ -114,7 +114,7 @@ void Checks_Sentences::check (map <int, string> texts)
   }
   
   // Go through the characters.
-  int characterCount = characters.size ();
+  int characterCount = static_cast<int>(characters.size ());
   for (int i = 0; i < characterCount; i++) {
     // Store current verse number in the object.
     verseNumber = verse_numbers [i];
@@ -208,7 +208,7 @@ void Checks_Sentences::paragraphs (vector <string> paragraph_start_markers,
       if (!in_array (paragraph_marker, within_sentence_paragraph_markers)) {
         string context = verses_paragraph.begin()->second;
         context = unicode_string_substr (context, 0, 15);
-        checkingResults.push_back (make_pair (verse, translate ("Paragraph does not start with a capital:") + " " + context));
+        checkingResults.push_back (pair (verse, translate ("Paragraph does not start with a capital:") + " " + context));
       }
     }
     
@@ -241,11 +241,11 @@ void Checks_Sentences::paragraphs (vector <string> paragraph_start_markers,
       }
       if (next_paragraph_marker.empty () || (!in_array (next_paragraph_marker, within_sentence_paragraph_markers))) {
         string context = verses_paragraph.rbegin()->second;
-        int length = unicode_string_length (character);
+        size_t length = unicode_string_length (character);
         if (length >= 15) {
           context = unicode_string_substr (context, length - 15, 15);
         }
-        checkingResults.push_back (make_pair (verse, translate ("Paragraph does not end with an end marker:") + " " + context));
+        checkingResults.push_back (pair (verse, translate ("Paragraph does not end with an end marker:") + " " + context));
       }
     }
     
@@ -296,7 +296,7 @@ void Checks_Sentences::addResult (string text, int modifier)
     text += ": " + previousFragment + character + nextFragment;
   }
   // Store checking result.
-  checkingResults.push_back (make_pair (verseNumber, text));
+  checkingResults.push_back (pair (verseNumber, text));
 }
 
 
