@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CHECKS_SETTINGS_PAIRS_H
-#define INCLUDED_CHECKS_SETTINGS_PAIRS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 string checks_settingspairs_url ();
 bool checks_settingspairs_acl (void * webserver_request);
 string checks_settingspairs (void * webserver_request);
-
-
-#endif
