@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -43,10 +43,9 @@ string checks_settingssentences_url ()
 }
 
 
-bool checks_settingssentences_acl (void * webserver_request)
+bool checks_settingssentences_acl ([[maybe_unused]] void * webserver_request)
 {
 #ifdef HAVE_CLIENT
-  (void) webserver_request;
   return true;
 #else
   return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
@@ -56,7 +55,7 @@ bool checks_settingssentences_acl (void * webserver_request)
 
 string checks_settingssentences (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   
   string page;
@@ -67,7 +66,7 @@ string checks_settingssentences (void * webserver_request)
   Assets_View view;
   
   
-  string bible = access_bible_clamp (webserver_request, request->database_config_user()->getBible ());
+  string bible = AccessBible::Clamp (webserver_request, request->database_config_user()->getBible ());
   
   
   if (request->post.count ("capitals")) {
