@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CLASSES_MERGE_H
-#define INCLUDED_CLASSES_MERGE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Merge_Conflict
 {
 public:
@@ -32,7 +29,7 @@ public:
   string prioritized_change;
   string result;
   string subject;
+  // The following shows the passage where the conflict occurred.
+  int book = 0;
+  int chapter = 0;
 };
-
-
-#endif
