@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CLIENT_LOGIC_H
-#define INCLUDED_CLIENT_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 bool client_logic_client_enabled ();
 void client_logic_enable_client (bool enable);
 string client_logic_url (string address, int port, string path);
@@ -37,6 +34,8 @@ string client_logic_link_to_cloud (string path, string linktext);
 string client_logic_usfm_resources_path ();
 void client_logic_usfm_resources_update ();
 vector <string> client_logic_usfm_resources_get ();
-
-
-#endif
+string client_logic_get_username ();
+string client_logic_no_cache_resources_path ();
+void client_logic_no_cache_resource_add (string name);
+void client_logic_no_cache_resource_remove (string name);
+vector <string> client_logic_no_cache_resources_get ();
