@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -52,5 +52,6 @@ extern map <string, int> config_globals_resource_window_positions;
 extern string config_globals_pages_to_open;
 extern bool config_globals_hide_bible_resources;
 extern bool config_globals_running_on_chrome_os;
-extern bool config_globals_log_incoming_connections;
-
+extern bool config_globals_log_network;
+extern string config_globals_negotiated_port_number;
+extern bool config_globals_has_crashed_while_mailing;
