@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_BIBLEACTIONS_H
-#define INCLUDED_DATABASE_BIBLEACTIONS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_BibleActions
 {
 public:
@@ -39,6 +36,3 @@ public:
 private:
   const char * filename ();
 };
-
-
-#endif
