@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_BIBLES_H
-#define INCLUDED_DATABASE_BIBLES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Bibles
 {
 public:
@@ -42,12 +39,13 @@ public:
   void optimize ();
 private:
   string mainFolder ();
+  string icfURL ();
+  string icfBibleName ();
 public:
   string bibleFolder (string bible);
 private:
   string bookFolder (string bible, int book);
+  vector <string> icfBooks ();
   string chapterFolder (string bible, int book, int chapter);
+  vector <string> icfChapters (int book);
 };
-
-
-#endif
