@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_BOOKS_H
-#define INCLUDED_DATABASE_BOOKS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Books
 {
 public:
@@ -38,13 +35,9 @@ public:
   static int getIdFromBibleworks (string bibleworks);
   static int getIdLikeText (string text);
   static int getIdFromOnlinebible (string onlinebible);
-  static int getIdLastEffort (string text);
   static string getOnlinebibleFromId (int id);
   static int getOrderFromId (int id);
   static string getType (int id);
 private:
   static unsigned int data_count ();
 };
-
-
-#endif
