@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,9 +17,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_CONFIRM_H
-#define INCLUDED_DATABASE_CONFIRM_H
-
+#pragma once
 
 #include <config/libraries.h>
 
@@ -31,15 +29,18 @@ class Database_Confirm
 {
 public:
   void create ();
+  void upgrade ();
   void optimize ();
-  unsigned int getNewID ();
-  bool IDExists (unsigned int id);
-  void store (unsigned int id, string query, string to, string subject, string body);
-  unsigned int searchID (string subject);
-  string getQuery (unsigned int id);
-  string getMailTo (unsigned int id);
-  string getSubject (unsigned int id);
-  string getBody (unsigned int id);
+  unsigned int get_new_id ();
+  bool id_exists (unsigned int id);
+  void store (unsigned int id, string query, string to, string subject, string body, string username);
+  unsigned int search_id (string subject);
+  vector <int> get_ids ();
+  string get_query (unsigned int id);
+  string get_mail_to (unsigned int id);
+  string get_subject (unsigned int id);
+  string get_body (unsigned int id);
+  string get_username (unsigned int id);
   void erase (unsigned int id);
   void trim ();
 private:
@@ -49,5 +50,3 @@ private:
 
 #endif
 
-
-#endif
