@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_LOCALIZATION_H
-#define INCLUDED_DATABASE_LOCALIZATION_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Localization
 {
 public:
@@ -37,5 +34,3 @@ private:
   sqlite3 * connect ();
 };
 
-
-#endif
