@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_LOGS_H
-#define INCLUDED_DATABASE_LOGS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Logs
 {
 public:
@@ -35,6 +32,3 @@ public:
   static void clear ();
   static string folder ();
 };
-
-
-#endif
