@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_MAIL_H
-#define INCLUDED_DATABASE_MAIL_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Mail_User
 {
 public:
@@ -32,7 +29,6 @@ public:
   string subject;
 };
 
-
 class Database_Mail_Item
 {
 public:
@@ -41,7 +37,6 @@ public:
   string body;
 };
 
-
 class Database_Mail
 {
 public:
@@ -62,6 +57,3 @@ private:
   sqlite3 * connect ();
   void * webserver_request;
 };
-
-
-#endif
