@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,29 +17,24 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_NAVIGATION_H
-#define INCLUDED_DATABASE_NAVIGATION_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/passage.h>
 
-
 class Database_Navigation
 {
 public:
   void create ();
   void trim ();
   void record (int time, string user, int book, int chapter, int verse);
-  bool previousExists (const string& user);
-  bool nextExists (const string& user);
-  Passage getPrevious (const string& user);
-  Passage getNext (const string& user);
+  bool previous_exists (const string& user);
+  bool next_exists (const string& user);
+  Passage get_previous (const string& user);
+  Passage get_next (const string& user);
+  vector <Passage> get_history (const string& user, int direction);
 private:
   sqlite3 * connect ();
-  int getPreviousId (const string& user);
-  int getNextId (const string& user);
+  int get_previous_id (const string& user);
+  int get_next_id (const string& user);
 };
-
-
-#endif
