@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -136,13 +136,13 @@ void Database_Notes::create ()
 
 string Database_Notes::database_path ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "notes.sqlite");
+  return filter_url_create_root_path ({database_logic_databases (), "notes.sqlite"});
 }
 
 
 string Database_Notes::checksums_database_path ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "notes_checksums.sqlite");
+  return filter_url_create_root_path ({database_logic_databases (), "notes_checksums.sqlite"});
 }
 
 
@@ -192,7 +192,7 @@ void Database_Notes::trim ()
   vector <string> bits1 = filter_url_scandir (main_folder);
   for (auto bit1 : bits1) {
     if (bit1.length () == 3) {
-      string folder = filter_url_create_path (main_folder, bit1);
+      string folder = filter_url_create_path ({main_folder, bit1});
       vector <string> bits2 = filter_url_scandir (folder);
       if (bits2.empty ()) {
         Database_Logs::log (message + folder);
@@ -200,7 +200,7 @@ void Database_Notes::trim ()
       }
       for (auto bit2 : bits2) {
         if (bit2.length () == 3) {
-          string folder = filter_url_create_path (main_folder, bit1, bit2);
+          string folder = filter_url_create_path ({main_folder, bit1, bit2});
           vector <string> bits3 = filter_url_scandir (folder);
           if (bits3.empty ()) {
             Database_Logs::log (message + folder);
@@ -249,11 +249,11 @@ void Database_Notes::sync ()
     // It used conversion to int before to determine it was a real note,
     // with the result that it missed 10% of the notes, which subsequently got deleted, oops!
     if (bit1.length () == 3) {
-      vector <string> bits2 = filter_url_scandir (filter_url_create_path (main_folder, bit1));
+      vector <string> bits2 = filter_url_scandir (filter_url_create_path ({main_folder, bit1}));
       for (auto & bit2 : bits2) {
         // Old storage mechanism, e.g. folder "425".
         if (bit2.length () == 3) {
-          vector <string> bits3 = filter_url_scandir (filter_url_create_path (main_folder, bit1, bit2));
+          vector <string> bits3 = filter_url_scandir (filter_url_create_path ({main_folder, bit1, bit2}));
           for (auto & bit3 : bits3) {
             if (bit3.length () == 3) {
               int identifier = convert_to_int (bit1 + bit2 + bit3);
@@ -405,7 +405,7 @@ void Database_Notes::update_database_internal (int identifier, int modified, str
 
 string Database_Notes::main_folder_path ()
 {
-  return filter_url_create_root_path ("consultations");
+  return filter_url_create_root_path ({"consultations"});
 }
 
 
@@ -416,7 +416,7 @@ string Database_Notes::note_file (int identifier)
   string sidentifier = convert_to_string (identifier);
   string folder = sidentifier.substr (0, 3);
   string file = sidentifier.substr (3, 6) + ".json";
-  return filter_url_create_path (main_folder_path (), folder, file);
+  return filter_url_create_path ({main_folder_path (), folder, file});
 }
 
 
@@ -503,7 +503,8 @@ string Database_Notes::assemble_contents (int identifier, string contents)
   string new_contents = get_contents (identifier);
   int time = filter_date_seconds_since_epoch ();
   string datetime = convert_to_string (filter_date_numerical_month_day (time)) + "/" + convert_to_string (filter_date_numerical_month (time)) + "/" + convert_to_string (filter_date_numerical_year (time));
-  string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string user = request->session_logic ()->currentUser ();
 
   // To make the notes more readable, add whitespace between the comments.
   bool is_initial_comment = new_contents.empty ();
@@ -619,7 +620,8 @@ int Database_Notes::store_new_note (const string& bible, int book, int chapter,
 // limit: If >= 0, it indicates the starting limit for the selection.
 vector <int> Database_Notes::select_notes (vector <string> bibles, int book, int chapter, int verse, int passage_selector, int edit_selector, int non_edit_selector, const string& status_selector, string bible_selector, string assignment_selector, bool subscription_selector, int severity_selector, int text_selector, const string& search_text, int limit)
 {
-  string username = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string username = request->session_logic ()->currentUser ();
   vector <int> identifiers;
   // SQL SELECT statement.
   string query = notes_select_identifier ();
@@ -897,7 +899,8 @@ void Database_Notes::add_comment (int identifier, const string& comment)
 // Subscribe the current user to the note identified by identifier.
 void Database_Notes::subscribe (int identifier)
 {
-  string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string user = request->session_logic ()->currentUser ();
   subscribe_user (identifier, user);
 }
 
@@ -979,7 +982,8 @@ bool Database_Notes::is_subscribed (int identifier, const string& user)
 // Unsubscribes the currently logged in user from the note identified by identifier.
 void Database_Notes::unsubscribe (int identifier)
 {
-  string user = ((Webserver_Request *) webserver_request)->session_logic ()->currentUser ();
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string user = request->session_logic ()->currentUser ();
   unsubscribe_user (identifier, user);
 }
 
@@ -1762,7 +1766,7 @@ vector <int> Database_Notes::get_notes_in_range_for_bibles (int lowId, int highI
 
 string Database_Notes::availability_flag ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "notes.busy");
+  return filter_url_create_root_path ({database_logic_databases (), "notes.busy"});
 }
 
 
@@ -1875,7 +1879,7 @@ vector <string> Database_Notes::set_bulk (string json)
   for (size_t i = 0; i < bulk.size (); i++) {
     
     // Get all the different fields for this note.
-    Object note = bulk.get<Object>(i);
+    Object note = bulk.get<Object>((int)i);
     string assigned = note.get<String> ("a");
     string bible = note.get<String> ("b");
     string contents = note.get<String> ("c");
