@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,14 +17,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_OSHB_H
-#define INCLUDED_DATABASE_OSHB_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/passage.h>
 
-
 class Database_OsHb
 {
 public:
@@ -42,6 +39,3 @@ private:
   int get_id (const char * table_row, string item);
   string get_item (const char * item, int rowid);
 };
-
-
-#endif
