@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_STATE_H
-#define INCLUDED_DATABASE_STATE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_State
 {
 public:
@@ -38,6 +35,3 @@ private:
   static sqlite3 * connect ();
   static const char * name ();
 };
-
-
-#endif
