@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -42,6 +42,6 @@ string Database_Volatile::filename (int id, string key)
 {
   string identifier = filter_url_clean_filename (convert_to_string (id));
   key = filter_url_clean_filename (key);
-  string path = filter_url_create_root_path (filter_url_temp_dir (), "volatile__" + identifier + "__" + key);
+  string path = filter_url_create_root_path ({filter_url_temp_dir (), "volatile__" + identifier + "__" + key});
   return path;
 }
