@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -32,6 +32,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #endif
 #include <resource/external.h>
 #include <config/globals.h>
+#include <library/bibledit.h>
+#include <developer/logic.h>
 
 
 const char * developer_index_url ()
@@ -48,7 +50,7 @@ bool developer_index_acl (void * webserver_request)
 
 string developer_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   if (request->query.count ("log")) {
     string message = request->query ["log"];
@@ -132,6 +134,24 @@ string developer_index (void * webserver_request)
     tasks_logic_queue (MAINTAINDATABASE);
     view.set_variable ("success", "Starting to maintain the databases");
   }
+
+  if (debug == "accordance") {
+    string reference = bibledit_get_reference_for_accordance ();
+    view.set_variable ("success", "Accordance reference: " + reference);
+    bibledit_put_reference_from_accordance("PSA 3:2");
+  }
+
+  if (debug == "expirefreeindonesian") {
+    if (config_logic_indonesian_cloud_free ()) {
+      tasks_logic_queue (EXPIREINDONESIANFREEUSERS);
+      view.set_variable ("success", "Task was started");
+    } else view.set_variable ("error", "Not configured");
+  }
+  
+  if (debug == "changes") {
+    developer_logic_import_changes ();
+    view.set_variable ("success", "Task was done see Journal");
+  }
   
   view.set_variable ("code", code);
 
