@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@
  */
 
 
-#ifndef INCLUDED_DIALOG_BOOKS_H
-#define INCLUDED_DIALOG_BOOKS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Dialog_Books
 {
 public:
@@ -38,6 +35,3 @@ private:
   vector <int> include;
   vector <int> exclude;
 };
-
-
-#endif
