@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@
  */
 
 
-#ifndef INCLUDED_DIALOG_COLOR_H
-#define INCLUDED_DIALOG_COLOR_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Dialog_Color
 {
 public:
@@ -35,6 +32,3 @@ private:
   void * assets_view = NULL;
   string base_url;
 };
-
-
-#endif
