@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -50,15 +50,14 @@ string edit_index_url ()
 bool edit_index_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return write;
 }
 
 
 string edit_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   
   bool touch = request->session_logic ()->touchEnabled ();
@@ -70,7 +69,7 @@ string edit_index (void * webserver_request)
     int switchverse = 1;
     if (request->query.count ("switchverse")) switchverse = convert_to_int (request->query ["switchverse"]);
     Ipc_Focus::set (request, switchbook, switchchapter, switchverse);
-    Navigation_Passage::recordHistory (request, switchbook, switchchapter, switchverse);
+    Navigation_Passage::record_history (request, switchbook, switchchapter, switchverse);
   }
 
   
@@ -90,7 +89,7 @@ string edit_index (void * webserver_request)
     string changebible = request->query ["changebible"];
     if (changebible == "") {
       Dialog_List dialog_list = Dialog_List ("index", translate("Select which Bible to open in the editor"), "", "");
-      vector <string> bibles = access_bible_bibles (request);
+      vector <string> bibles = AccessBible::Bibles (request);
       for (auto & bible : bibles) {
         dialog_list.add_row (bible, "changebible", bible);
       }
@@ -114,8 +113,8 @@ string edit_index (void * webserver_request)
   
   
   // Active Bible, and check access.
-  string bible = access_bible_clamp (request, request->database_config_user()->getBible ());
-  if (request->query.count ("bible")) bible = access_bible_clamp (request, request->query ["bible"]);
+  string bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
+  if (request->query.count ("bible")) bible = AccessBible::Clamp (request, request->query ["bible"]);
   view.set_variable ("bible", bible);
   
   
@@ -126,11 +125,12 @@ string edit_index (void * webserver_request)
   int verticalCaretPosition = request->database_config_user ()->getVerticalCaretPosition (); 
   string script =
   "var editorChapterLoaded = '" + locale_logic_text_loaded () + "';\n"
+  "var editorChapterUpdating = '" + locale_logic_text_updating () + "';\n"
+  "var editorChapterUpdated = '" + locale_logic_text_updated () + "';\n"
   "var editorWillSave = '" + locale_logic_text_will_save () + "';\n"
   "var editorChapterSaving = '" + locale_logic_text_saving () + "';\n"
   "var editorChapterSaved = '" + locale_logic_text_saved () + "';\n"
   "var editorChapterRetrying = '" + locale_logic_text_retrying () + "';\n"
-  "var editorChapterReformat = '" + locale_logic_text_reformat () + "';\n"
   "var editorChapterVerseUpdatedLoaded = '" + locale_logic_text_reload () + "';\n"
   "var verticalCaretPosition = " + convert_to_string (verticalCaretPosition) + ";\n"
   "var verseSeparator = '" + Database_Config_General::getNotesVerseSeparator () + "';\n";
@@ -140,9 +140,15 @@ string edit_index (void * webserver_request)
   
   string clss = Filter_Css::getClass (bible);
   string font = Fonts_Logic::getTextFont (bible);
+  int current_theme_index = convert_to_int(request->database_config_user ()->getCurrentTheme ());
   int direction = Database_Config_Bible::getTextDirection (bible);
   int lineheight = Database_Config_Bible::getLineHeight (bible);
   int letterspacing = Database_Config_Bible::getLetterSpacing (bible);
+  string versebeam_current_theme = Filter_Css::theme_picker (current_theme_index, 5);
+  if (versebeam_current_theme == "") versebeam_current_theme = "versebeam";
+  view.set_variable ("versebeam_theme_color", versebeam_current_theme);
+  view.set_variable ("editor_theme_color", Filter_Css::theme_picker (current_theme_index, 2));
+  view.set_variable ("active_editor_theme_color", Filter_Css::theme_picker (current_theme_index, 3));
   view.set_variable ("custom_class", clss);
   view.set_variable ("custom_css", Filter_Css::getCss (clss,
                                                        Fonts_Logic::getFontPath (font),
@@ -161,6 +167,9 @@ string edit_index (void * webserver_request)
   if (!basic_mode && request->database_config_user ()->getFastEditorSwitchingAvailable ()) {
     view.enable_zone ("fastswitcheditor");
   }
+  if (config_logic_indonesian_cloud_free ()) {
+    view.enable_zone ("fastswitcheditor");
+  }
 
   
   // Whether to enable the styles button.
