@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,15 +33,13 @@ $ (document).ready (function ()
 
   navigationNewPassage ();
   
-  $ (window).on ("unload", editorUnload);
-
-  editorIdPollerTimeoutStart ();
+  $ (window).on ("unload", edit2SaveChapter);
 
   editorBindUnselectable ();
   $ ("#stylebutton").on ("click", editorStylesButtonHandler);
   $ (window).on ("keydown", editorWindowKeyHandler);
   
-  positionCaretViaAjax ();
+  edit2PositionCaretViaAjaxStart ();
 
   if (swipe_operations) {
     $ ("body").swipe ( {
@@ -55,6 +53,13 @@ $ (document).ready (function ()
   }
 
   $ ("#editor").on ("click", editorNoteCitationClicked);
+  
+  $ ("#editor").bind ("paste", editorClipboardPasteHandler);
+
+  setTimeout (edit2CoordinatingTimeout, 500);
+
+  document.body.addEventListener('paste', ChapterEditorHandlePaste);
+
 });
 
 
@@ -96,6 +101,21 @@ function editorInitialize ()
   // Event handlers.
   quill.on ("text-change", editorTextChangeHandler);
   quill.on ("selection-change", editorSelectionChangeHandler);
+  
+  // Clear undo/redo stack.
+  quill.history.clear();
+}
+
+
+// This fixes an issue where upon pasting text in the editor,
+// the editor scrolls to the very top of the text.
+// If the text is long, then the focused verse is thrown off the screen.
+// Here it fixes that.
+// https://github.com/bibledit/cloud/issues/428
+function editorClipboardPasteHandler (event)
+{
+  var currentScrollTop = $("#workspacewrapper").scrollTop();
+  $("#workspacewrapper").animate({ scrollTop: currentScrollTop }, 100);
 }
 
 
@@ -124,10 +144,10 @@ function navigationNewPassage ()
   } else {
     return;
   }
-
+  
   if ((editorNavigationBook != editorLoadedBook) || (editorNavigationChapter != editorLoadedChapter)) {
-    editorSaveChapter ();
-    editorLoadChapter (false);
+    edit2SaveChapter ();
+    editorLoadChapter ();
   } else {
     editorScheduleCaretPositioning ();
   }
@@ -156,22 +176,19 @@ var editorLoadedBook;
 var editorLoadedChapter;
 var editorReferenceText;
 var editorTextChanged = false;
-var editorCaretPosition = 0;
-var editorSaveAsync;
+var edit2CaretPosition = 0;
 var editorSaving = false;
 var editorWriteAccess = false;
-var editorLoadDate = new Date(0);
-var editorSaveDate = new Date(0);
 
 
-function editorLoadChapter (reload)
+function editorLoadChapter ()
 {
   editorLoadedBible = navigationBible;
   editorLoadedBook = editorNavigationBook;
   editorLoadedChapter = editorNavigationChapter;
   editorChapterIdOnServer = 0;
-  editorCaretPosition = getCaretPosition ();
-  editorCaretInitialized = false;
+  edit2CaretPosition = getCaretPosition ();
+  edit2CaretInitialized = false;
   $.ajax ({
     url: "load",
     type: "GET",
@@ -192,7 +209,11 @@ function editorLoadChapter (reload)
       response = checksum_receive (response);
       if (response !== false) {
         // Only load new text when it is different.
-        if (response != editorGetHtml ()) {
+        // Extract the plain text from the html and compare that.
+        // https://github.com/bibledit/cloud/issues/449
+        var responseText = $(response).text();
+        var editorText = $(editorGetHtml ()).text();
+        if (responseText != editorText) {
           // Destroy existing editor.
           if (quill) delete quill;
           // Load the html in the DOM.
@@ -206,34 +227,25 @@ function editorLoadChapter (reload)
           // Feedback.
           editorStatus (editorChapterLoaded);
         }
-        // Reference for comparison at save time.
+        // Reference for comparison at save or update time.
         editorReferenceText = editorGetHtml ();
-        // Position caret straightaway.
-        if (reload) {
-          positionCaret (editorCaretPosition);
-        }
+        // Position caret.
         editorScheduleCaretPositioning ();
-        // Alert on reloading soon after save, or after text reload.
-        // https://github.com/bibledit/cloud/issues/346
-        editorLoadDate = new Date();
-        var seconds = (editorLoadDate.getTime() - editorSaveDate.getTime()) / 1000;
-        if ((seconds < 2) || reload) {
-          if (editorWriteAccess) editorReloadAlert (editorChapterVerseUpdatedLoaded); // Todo
-        }
       } else {
         // Checksum error: Reload.
-        editorLoadChapter (false);
+        editorLoadChapter ();
       }
-      editorCaretInitialized = false;
+      edit2CaretInitialized = false;
     },
   });
 }
 
 
-function editorSaveChapter (sync)
+function edit2SaveChapter ()
 {
+  editorStatus ("");
   if (editorSaving) {
-    editorContentChangedTimeoutStart ();
+    edit2ContentChanged ();
     return;
   }
   if (!editorWriteAccess) return;
@@ -245,38 +257,25 @@ function editorSaveChapter (sync)
   editorStatus (editorChapterSaving);
   editorReferenceText = html;
   editorChapterIdOnServer = 0;
-  editorIdPollerTimeoutStop ();
-  editorSaveAsync = true;
-  if (sync) editorSaveAsync = false;
   var encodedHtml = filter_url_plus_to_tag (html);
   var checksum = checksum_get (encodedHtml);
   editorSaving = true;
   $.ajax ({
     url: "save",
     type: "POST",
-    async: editorSaveAsync,
+    async: false,
     data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter, html: encodedHtml, checksum: checksum, id: chapterEditorUniqueID },
     success: function (response) {
       editorStatus (response);
-      if (response == editorChapterReformat) {
-        editorLoadChapter (true);
-      }
     },
     error: function (jqXHR, textStatus, errorThrown) {
       editorStatus (editorChapterRetrying);
       editorReferenceText = "";
-      editorContentChanged ();
-      if (!editorSaveAsync) editorSaveChapter (true);
+      edit2ContentChanged ();
+      edit2SaveChapter ();
     },
     complete: function (xhr, status) {
-      editorIdPollerTimeoutStart ();
-      editorSaveAsync = true;
       editorSaving = false;
-      editorSaveDate = new Date();
-      var seconds = (editorSaveDate.getTime() - editorLoadDate.getTime()) / 1000;
-      if (seconds < 2) {
-        if (editorWriteAccess) editorReloadAlert (editorChapterVerseUpdatedLoaded); // Todo
-      }
     },
   });
 }
@@ -284,7 +283,7 @@ function editorSaveChapter (sync)
 
 function editorGetHtml ()
 {
-  var html = $ (".ql-editor").html ();
+  var html = $ ("#editor > .ql-editor").html ();
   // Remove verse focus class name, if it is:
   // * the only class name.
   html = html.split (' class="versebeam"').join ('');
@@ -308,35 +307,77 @@ Portion dealing with triggers for when the editor's content changes.
 */
 
 
-var editorContentChangedTimeoutId;
+// Three combined lists store information about edits made in the editor,
+// during the time span between
+// 1. the moment the changes are sent to the server/device,
+// when there is a delay in the network, and
+// 2. the moment the updates for the editor come back from the server/device.
+// Storage as follows:
+// 1. Offsets at which...
+// 2. The given number of characters were inserted, and...
+// 3. The given number of characters were deleted.
+// With 2-byte UTF-16 characters, one character is given as a "1" in the lists.
+// With 4-byte UTF-16 characters, one characters is represented by a "2" in the lists.
+var edit2EditorChangeOffsets = [];
+var edit2EditorChangeInserts = [];
+var edit2EditorChangeDeletes = [];
 
 
 // Arguments: delta: Delta, oldContents: Delta, source: String
 function editorTextChangeHandler (delta, oldContents, source)
 {
-  editorContentChanged ();
+  // Record the change.
+  // It gives 4-byte UTF-16 characters as length value 2 instead of 1.
+  var retain = 0;
+  var insert = 0;
+  var del = 0;
+  for (let i = 0; i < delta.ops.length; i++) {
+    let obj = delta.ops[i];
+    if (obj.retain) retain = obj.retain;
+    // For Unicode handling, see:
+    // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/length
+    if (obj.insert) insert = obj.insert.length;
+    if (obj.delete) del = obj.delete;
+  }
+  edit2EditorChangeOffsets.push(retain);
+  edit2EditorChangeInserts.push(insert);
+  edit2EditorChangeDeletes.push(del);
+  // Ensure that it does not delete a chapter number or verse number.
+  if (!delta.ops [0].retain) {
+    quill.history.undo ();
+  }
+  // Start save delay timer.
+  edit2ContentChanged ();
+  // Set a flag for the undo workaround.
+  edit2UndoChanged = true;
 }
 
 
-function editorContentChanged ()
+var edit2ContentChangedTimeoutId;
+
+
+function edit2ContentChanged ()
 {
   if (!editorWriteAccess) return;
   editorTextChanged = true;
   editorStatus (editorWillSave);
-  editorContentChangedTimeoutStart ();
+  if (edit2ContentChangedTimeoutId) {
+    clearTimeout (edit2ContentChangedTimeoutId);
+  }
+  edit2ContentChangedTimeoutId = setTimeout (edit2EditorTriggerSave, 1000);
 }
 
 
-function editorContentChangedTimeoutStart ()
+function edit2EditorTriggerSave ()
 {
-  if (editorContentChangedTimeoutId) clearTimeout (editorContentChangedTimeoutId);
-  editorContentChangedTimeoutId = setTimeout (editorSaveChapter, 1000);
-}
-
-
-function editorUnload ()
-{
-  editorSaveChapter (true);
+  if (!edit2UpdateTrigger) {
+    edit2UpdateTrigger = true;
+  } else {
+    if (edit2ContentChangedTimeoutId) {
+      clearTimeout (edit2ContentChangedTimeoutId);
+    }
+    edit2ContentChangedTimeoutId = setTimeout (edit2EditorTriggerSave, 400);
+  }
 }
 
 
@@ -348,41 +389,28 @@ Section for polling the server for updates on the loaded chapter.
 
 
 var editorChapterIdOnServer = 0;
-var editorChapterIdPollerTimeoutId;
 
 
-function editorIdPollerTimeoutStart ()
-{
-  editorIdPollerTimeoutStop ();
-  editorChapterIdPollerTimeoutId = setTimeout (editorEditorPollId, 1000);
-}
-
-
-function editorIdPollerTimeoutStop ()
-{
-  if (editorChapterIdPollerTimeoutId) clearTimeout (editorChapterIdPollerTimeoutId);
-}
-
-
-function editorEditorPollId ()
+function edit2EditorPollId ()
 {
+  edit2AjaxActive = true;
   $.ajax ({
-    url: "id",
+    url: "../editor/id",
     type: "GET",
     data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter },
     success: function (response) {
-      if (!editorSaving) {
-        if (editorChapterIdOnServer != 0) {
-          if (response != editorChapterIdOnServer) {
-            editorLoadChapter (true);
-            editorChapterIdOnServer = 0;
-          }
+      if (editorChapterIdOnServer != 0) {
+        if (response != editorChapterIdOnServer) {
+          // The chapter identifier changed.
+          // That means that likely there's updated text on the server.
+          // Start the routine to load any possible updates into the editor.
+          edit2UpdateTrigger = true;
         }
-        editorChapterIdOnServer = response;
       }
+      editorChapterIdOnServer = response;
     },
     complete: function (xhr, status) {
-      editorIdPollerTimeoutStart ();
+      edit2AjaxActive = false;
     }
   });
 }
@@ -409,81 +437,67 @@ function editorSelectionChangeHandler (range, oldRange, source)
   // Bail out if text was selected.
   if (range.length != 0) return;
   
-  editorCaretMovedTimeoutStart ();
+  edit2CaretMovedTimeoutStart ();
 }
 
 
-var editorCaretMovedTimeoutId;
-var editorCaretMovedAjaxRequest;
-var editorCaretMovedAjaxOffset;
-var editorCaretInitialized = false;
+var edit2CaretInitialized = false;
+var edit2CaretMovedTimeoutId;
 
 
-function editorCaretMovedTimeoutStart ()
+function edit2CaretMovedTimeoutStart ()
 {
-  if (editorCaretMovedTimeoutId) clearTimeout (editorCaretMovedTimeoutId);
-  editorCaretMovedTimeoutId = setTimeout (editorHandleCaretMoved, 200);
+  if (edit2CaretMovedTimeoutId) clearTimeout (edit2CaretMovedTimeoutId);
+  edit2CaretMovedTimeoutId = setTimeout (edit2CaretMovedTimeoutFinish, 200);
 }
 
 
-function editorHandleCaretMoved ()
+function edit2CaretMovedTimeoutFinish ()
+{
+  // Since the user moved the caret by hand,
+  // cancel any scheduled caret positioning.
+  edit2PositionCaretViaAjaxStop ();
+  // Trigger the caret moved handler.
+  edit2CaretMovedTrigger = true;
+}
+
+
+function edit2HandleCaretMoved ()
 {
-  // If the text in the editor has been changed, and therefore not saved,
-  // or is being saved now, postpone handling the moved caret.
-  // It is important to also delay the handler "while" the text is being saved,
-  // because there have been situations that javascript initiated the save operation,
-  // shortly after that the moved caret handler via AJAX,
-  // and that the server completed processing the caret handler before it had completed the save operations,
-  // which led to inaccurate caret position calculations, which caused symptoms like a "jumping caret".
-  if (editorTextChanged || editorSaving) {
-    editorCaretMovedTimeoutStart ();
-    return;
-  }
-  
   // If the caret has not yet been positioned, postpone the action.
-  if (!editorCaretInitialized) {
-    editorCaretMovedTimeoutStart ();
-    positionCaretViaAjax ();
+  if (!edit2CaretInitialized) {
+    edit2CaretMovedTimeoutStart ();
+    edit2PositionCaretViaAjaxStart ();
     return;
   }
 
   if (quill.hasFocus ()) {
-    // Cancel any previous ajax request that might still be incompleted.
-    // This is to avoid the caret jumping on slower or unstable connections.
-    if (editorCaretMovedAjaxRequest && editorCaretMovedAjaxRequest.readystate != 4) {
-      editorCaretMovedAjaxRequest.abort();
-    }
-    // Record the offset of the caret at the start of the ajax request.
-    editorCaretMovedAjaxOffset = getCaretPosition ();
     // Initiate a new ajax request.
-    editorCaretMovedAjaxRequest = $.ajax ({
+    edit2AjaxActive = true;
+    $.ajax ({
       url: "navigate",
       type: "GET",
-      data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter, offset: editorCaretMovedAjaxOffset },
+      data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter, offset: getCaretPosition () },
       success: function (response) {
         if (response != "") {
-          var offset = getCaretPosition ();
-          // Take action only when the caret is still at the same position as it was when this ajax request was initiated.
-          if (offset == editorCaretMovedAjaxOffset) {
-            // Set the focused verse immediately,
-            // rather than waiting on the Navigator signal that likely will come later.
-            // This fixes a clicking / scrolling problem.
-            editorNavigationVerse = response;
-            editorScheduleWindowScrolling ();
-            editorHighlightVerseNumber ();
-          } else {
-            // Caret was moved during this AJAX operation: Reschedule it.
-            editorCaretMovedTimeoutStart ();
-          }
+          // Set the focused verse immediately,
+          // rather than waiting on the Navigator signal that likely will come later.
+          // This fixes a clicking / scrolling problem.
+          editorNavigationVerse = response;
+          editorScheduleWindowScrolling ();
+          editorHighlightVerseNumber ();
         }
       },
       error: function (jqXHR, textStatus, errorThrown) {
         // On (network) failure, reschedule the update.
-        editorCaretMovedTimeoutStart ();
+        edit2CaretMovedTimeoutStart ();
+      },
+      complete: function (xhr, status) {
+        edit2AjaxActive = false;
       }
     });
   } else {
-    editorCaretMovedTimeoutStart ();
+    edit2CaretMovedTimeoutStart ();
   }
 
   editorActiveStylesFeedback ();
@@ -496,6 +510,8 @@ Section with window events and their basic handlers.
 
 */
 
+var edit2UndoChanged = false;
+
 
 function editorWindowKeyHandler (event)
 {
@@ -509,6 +525,30 @@ function editorWindowKeyHandler (event)
   if (event.keyCode == 27) {
     editorClearStyles ();
   }
+  // Undo.
+  if ((event.metaKey == true) && (event.shiftKey == false) && (event.key == 'z')) {
+    edit2UndoChanged = false;
+    //var position = getCaretPosition ();
+    quill.history.undo();
+    if (edit2UndoChanged == false) {
+      // This should fix an issue with the Quill editor.
+      // When doing an undo, and the history stack is empty,
+      // the Quill editor places the caret at the end of the text block.
+      // The solution should have been to reposition the caret.
+      // But repositioning the caret appears not to work.
+      // After repositioning the caret, the caret remains at the end of the text block.
+      //positionCaret (position);
+      //positionCaretDelayed (position)
+      //quill.setSelection (position, 0, "silent");
+    }
+    return false;
+  }
+  // Redo.
+  if ((event.metaKey == true) && (event.shiftKey == true) && (event.key == 'z')) {
+    // Checking on 2020-11-26 the .redo() did not work.
+    quill.history.redo();
+    return false;
+  }
 }
 
 
@@ -548,10 +588,12 @@ function editorActiveStylesFeedback ()
 function editorSelectiveNotification (message)
 {
   if (message == editorChapterLoaded) return;
+  if (message == editorChapterUpdating) return;
+  if (message == editorChapterUpdated) return;
   if (message == editorWillSave) return;
   if (message == editorChapterSaving) return;
   if (message == editorChapterSaved) return;
-  if (message == editorChapterReformat) return;
+  if (message == "") return;
   notifyItError (message);
 }
 
@@ -572,6 +614,27 @@ function getCaretPosition ()
 }
 
 
+var edit2PositionCaretDelayedTimerId;
+var edit2PositionCaretValue;
+
+
+function positionCaretDelayed (position)
+{
+  if (edit2PositionCaretDelayedTimerId) {
+    clearTimeout (edit2PositionCaretDelayedTimerId);
+  }
+  edit2PositionCaretValue = position;
+  edit2PositionCaretDelayedTimerId = setTimeout (positionCaretDelayedTimeout, 100);
+}
+
+
+function positionCaretDelayedTimeout ()
+{
+  quill.setSelection (edit2PositionCaretValue, 0, "silent");
+  //positionCaret (edit2PositionCaretValue);
+}
+
+
 function positionCaret (position)
 {
   if (position == undefined) return;
@@ -584,18 +647,25 @@ function positionCaret (position)
 }
 
 
-var editorPositionCaretViaAjaxTimerId;
+var edit2PositionCaretViaAjaxTimerId;
 
 
-function positionCaretViaAjax ()
+function edit2PositionCaretViaAjaxStop ()
 {
+  if (edit2PositionCaretViaAjaxTimerId) {
+    clearTimeout (edit2PositionCaretViaAjaxTimerId);
+  }
+}
+
+function edit2PositionCaretViaAjaxStart ()
+{
+  edit2PositionCaretViaAjaxStop ();
   // Very frequent positioning calls have been seen in some browsers, so they are filtered here.
-  if (editorPositionCaretViaAjaxTimerId) clearTimeout (editorPositionCaretViaAjaxTimerId);
-  editorPositionCaretViaAjaxTimerId = setTimeout (positionCaretViaAjaxExecute, 100);
+  edit2PositionCaretViaAjaxTimerId = setTimeout (edit2PositionCaretViaAjaxStartExecute, 100);
 }
 
 
-function positionCaretViaAjaxExecute ()
+function edit2PositionCaretViaAjaxStartExecute ()
 {
   if (isNoVerseBook (editorLoadedBook)) return;
   $.ajax ({
@@ -611,7 +681,7 @@ function positionCaretViaAjaxExecute ()
         if ((offset < start) || (offset > end)) {
           positionCaret (start);
         }
-        editorCaretInitialized = true;
+        edit2CaretInitialized = true;
       }
       editorScheduleWindowScrolling ();
     },
@@ -690,7 +760,7 @@ function editorStylesButtonHandler ()
 {
   if (!editorWriteAccess) return;
   $.ajax ({
-    url: "styles",
+    url: "../editor/style",
     type: "GET",
     cache: false,
     success: function (response) {
@@ -720,6 +790,7 @@ function editorShowResponse (response)
   $ ("#nostyles").hide ();
   var area = $ ("#stylesarea");
   area.empty ();
+  area.addClass ('style-of-stylesarea');
   area.append (response);
 }
 
@@ -727,6 +798,7 @@ function editorShowResponse (response)
 function editorClearStyles ()
 {
   var area = $ ("#stylesarea");
+  area.removeClass ('style-of-stylesarea');
   area.empty ();
   $ ("#stylebutton").show ();
   $ ("#nostyles").show ();
@@ -764,7 +836,7 @@ function dynamicClickHandlers ()
 function requestStyle (style)
 {
   $.ajax ({
-    url: "styles",
+    url: "../editor/style",
     type: "GET",
     data: { style: style },
     cache: false,
@@ -778,10 +850,10 @@ function requestStyle (style)
         applyCharacterStyle (style);
       } else if (action == 'n') {
         applyNotesStyle (style);
-        editorContentChanged ();
+        edit2ContentChanged ();
       } else if (action == "m") {
         applyMonoStyle (style);
-        editorContentChanged ();
+        edit2ContentChanged ();
       }
     },
   });
@@ -791,7 +863,7 @@ function requestStyle (style)
 function displayAllStyles ()
 {
   $.ajax ({
-    url: "styles",
+    url: "../editor/style",
     type: "GET",
     data: { all: "" },
     cache: false,
@@ -888,7 +960,7 @@ Section for the notes.
 var editorInsertedNotesCount = 0;
 
 
-function applyNotesStyle (style) // Todo
+function applyNotesStyle (style)
 {
   if (!editorWriteAccess) return;
 
@@ -912,8 +984,8 @@ function applyNotesStyle (style) // Todo
   quill.setSelection (caret, 0);
   quill.insertText (caret, caller, "character", "notecall" + noteId, "user");
 
-  // Append note text to notes section. Todo
-  assetsEditorAddNote (quill, style, caller, noteId, editorNavigationChapter, editorNavigationVerse);
+  // Append note text to notes section.
+  assetsEditorAddNote (quill, style, caller, noteId, editorNavigationChapter, verseSeparator, editorNavigationVerse);
 
   editorInsertedNotesCount++;
   
@@ -998,7 +1070,7 @@ function editorPositioningTimerStart ()
 function editorPositioningRun ()
 {
   if (editorPendingCaretPositioning) {
-    positionCaretViaAjax ();
+    edit2PositionCaretViaAjaxStart ();
     editorPendingCaretPositioning = false;
     editorPendingWindowScrolling = false;
   }
@@ -1057,7 +1129,7 @@ Section for reload notifications.
 */
 
 
-function editorReloadAlert (message) // Todo
+function editorReloadAlert (message)
 {
   // Take action only if the editor has focus and the user can type in it.
   if (quill.hasFocus ()) {
@@ -1074,3 +1146,327 @@ function editorReloadAlertTimeout ()
   quill.focus ();
 }
 
+
+
+/*
+
+Section for the coordinating timer.
+This deals with the various events.
+It monitors the ongoing AJAX actions for loading and updating and saving.
+It decides which action to take.
+It ensures that no two actions overlap or interfere with one another.
+It also handles network latency,
+by ensuring that the next call to the server
+only occurs after the first call has been completed.
+https://github.com/bibledit/cloud/issues/424
+
+*/
+
+
+var edit2UpdateTrigger = false;
+var edit2CaretMovedTrigger = false;
+var edit2AjaxActive = false;
+var edit2PollSelector = 0;
+var edit2PollDate = new Date();
+
+
+function edit2CoordinatingTimeout ()
+{
+  // Handle situation that an AJAX call is ongoing.
+  if (edit2AjaxActive) {
+    
+  }
+  else if (edit2CaretMovedTrigger) {
+    edit2CaretMovedTrigger = false;
+    edit2HandleCaretMoved ();
+  }
+  else if (edit2UpdateTrigger) {
+    edit2UpdateTrigger = false;
+    edit2UpdateExecute ();
+  }
+  // Handle situation that no process is ongoing.
+  // Now the regular pollers can run again.
+  else {
+    // There are two regular pollers.
+    // Wait 500 ms, then start one of the pollers.
+    // So each poller runs once a second.
+    var difference = new Date () - edit2PollDate;
+    if (difference > 500) {
+      edit2PollSelector++;
+      if (edit2PollSelector > 1) edit2PollSelector = 0;
+      if (edit2PollSelector == 0) {
+        edit2EditorPollId ();
+      }
+      if (edit2PollSelector == 1) {
+
+      }
+      edit2PollDate = new Date();
+    }
+  }
+  setTimeout (edit2CoordinatingTimeout, 100);
+}
+
+
+
+/*
+
+Section for the smart editor updating logic.
+
+*/
+
+
+var editorHtmlAtStartOfUpdate = null;
+var useShadowQuill = false;
+
+
+function edit2UpdateExecute ()
+{
+  // Determine whether the conditions for an editor update are all met.
+  var goodToGo = true;
+  if (!editorLoadedBible) goodToGo = false;
+  if (!editorLoadedBook) goodToGo = false;
+  if (!editorLoadedChapter) goodToGo = false;
+  if (!goodToGo) {
+    return;
+  }
+
+  // Clear the editor's edits.
+  // The user can continue making changes in the editor.
+  // These changes get recorded.
+  edit2EditorChangeOffsets = [];
+  edit2EditorChangeInserts = [];
+  edit2EditorChangeDeletes = [];
+
+  // A snapshot of the text originally loaded in the editor via AJAX.
+  var encodedLoadedHtml = filter_url_plus_to_tag (editorReferenceText);
+
+  // A snapshot of the current editor text at this point of time.
+  editorHtmlAtStartOfUpdate = editorGetHtml();
+  var encodedEditedHtml = filter_url_plus_to_tag (editorHtmlAtStartOfUpdate);
+
+  // The editor "saves..." if there's changes, and "updates..." if there's no changes.
+  if (editorHtmlAtStartOfUpdate == editorReferenceText) {
+    editorStatus (editorChapterUpdating);
+  } else {
+    editorStatus (editorChapterSaving);
+  }
+
+  var checksum1 = checksum_get (encodedLoadedHtml);
+  var checksum2 = checksum_get (encodedEditedHtml);
+
+  edit2AjaxActive = true;
+
+  $.ajax ({
+    url: "update",
+    type: "POST",
+    async: true,
+    data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter, loaded: encodedLoadedHtml, edited: encodedEditedHtml, checksum1: checksum1, checksum2: checksum2, id: chapterEditorUniqueID },
+    error: function (jqXHR, textStatus, errorThrown) {
+      editorStatus (editorChapterRetrying);
+      edit2ContentChanged ();
+    },
+    success: function (response) {
+
+      // Flag for editor read-write or read-only.
+      // Do not set the read-only status of the editor here.
+      // This is already set at text-load.
+      // It is also dependent on the frame number the editor is in.
+      // To not make it more complex than needed, leave read-only out.
+      var readwrite = checksum_readwrite (response);
+
+      // Checksumming.
+      response = checksum_receive (response);
+      if (response !== false) {
+        
+        // Use a shadow copy of the Quill editor in case the user made edits
+        // between the moment the update routine was initiated,
+        // and the moment the updates from the server/device are being applied.
+        // This shadow copy will be updated with the uncorrected changes from the server/device.
+        // The html from this editor will then server as the "loaded text".
+        useShadowQuill = (edit2EditorChangeOffsets.length > 0);
+        if (useShadowQuill) startShadowQuill (editorHtmlAtStartOfUpdate);
+
+        // Split the response into the separate bits.
+        var bits = [];
+        bits = response.split ("#_be_#");
+
+        // The first bit is the feedback message to the user.
+        editorStatus (bits.shift());
+
+        // The next bit is the new chapter identifier.
+        oneverseChapterId = bits.shift();
+
+        // Apply the remaining data, the differences, to the editor.
+        while (bits.length > 0) {
+          var position = parseInt (bits.shift ());
+          var operator = bits.shift();
+          // Position 0 in the incoming changes always refers to the initial new line in the editor.
+          // Do not insert or delete that new line, but just apply any formatting there.
+          if (position == 0) {
+            if (operator == "p") {
+              var style = bits.shift ();
+              quill.formatLine (0, 0, {"paragraph": style}, "silent");
+              if (useShadowQuill) quill2.formatLine (0, 0, {"paragraph": style}, "silent");
+            }
+          } else {
+            // The initial new line is not counted in Quill.
+            position--;
+            // The position for the shadow copy of Quill, if it's there.
+            var position2 = position;
+            // Handle the insert operation.
+            if (operator == "i") {
+              // Get the information.
+              var text = bits.shift ();
+              var style = bits.shift ();
+              var size = parseInt (bits.shift());
+              // Correct the position
+              // and the positions stored during the update procedure's network latency.
+              position = oneverseUpdateIntermediateEdits (position, size, true, false);
+              // Handle the insert operation.
+              if (text == "\n") {
+                // New line.
+                quill.insertText (position, text, {}, "silent");
+                if (useShadowQuill) quill2.insertText (position2, text, {}, "silent");
+                quill.formatLine (position + 1, 1, {"paragraph": style}, "silent");
+                if (useShadowQuill) quill2.formatLine (position2 + 1, 1, {"paragraph": style}, "silent");
+              } else {
+                // Ordinary character: Insert formatted text.
+                quill.insertText (position, text, {"character": style}, "silent");
+                if (useShadowQuill) quill2.insertText (position2, text, {"character": style}, "silent");
+              }
+            }
+            // Handle delete operator.
+            else if (operator == "d") {
+              // Get the bits of information.
+              var size = parseInt (bits.shift());
+              // Correct the position and the positions
+              // stored during the update procedure's network latency.
+              position = oneverseUpdateIntermediateEdits (position, size, false, true);
+              // Do the delete operation.
+              quill.deleteText (position, size, "silent");
+              if (useShadowQuill) quill2.deleteText (position2, size, "silent");
+            }
+            // Handle format paragraph operator.
+            else if (operator == "p") {
+              var style = bits.shift ();
+              quill.formatLine (position + 1, 1, {"paragraph": style}, "silent");
+              if (useShadowQuill) quill2.formatLine (position2 + 1, 1, {"paragraph": style}, "silent");
+            }
+            // Handle format character operator.
+            else if (operator == "c") {
+              var style = bits.shift ();
+            }
+          }
+        }
+        
+      } else {
+        // If the checksum is not valid, the response will become false.
+        // Checksum error.
+        editorStatus (editorChapterRetrying);
+      }
+
+      // The browser may reformat the loaded html, so take the possible reformatted data for reference.
+      editorReferenceText = editorGetHtml ();
+      if (useShadowQuill) editorReferenceText = $ ("#edittemp > .ql-editor").html ();
+      $ ("#edittemp").empty ();
+      
+      // Create CSS for embedded styles.
+      css4embeddedstyles ();
+    },
+    complete: function (xhr, status) {
+      edit2AjaxActive = false;
+    }
+  });
+
+}
+
+                                          
+var quill2 = undefined;
+
+
+function startShadowQuill (html)
+{
+  if (quill2) delete quill2;
+  $ ("#edittemp").empty ();
+  $ ("#edittemp").append (html);
+  quill2 = new Quill ('#edittemp', { });
+}
+
+
+function oneverseUpdateIntermediateEdits (position, size, ins_op, del_op)
+{
+  // The offsets of the changes from the server/device are going to be corrected
+  // with the offsets of the edits made in the editor.
+  // This is to handle continued user-typing while the editor is being updated,
+  // Update, and get updated by, the edits made since the update operation began.
+  // UTF-16 characters 4 bytes long have a size of 2 in Javascript.
+  // So the routine takes care of that too.
+  var i;
+  for (i = 0; i < edit2EditorChangeOffsets.length; i++) {
+    // Any delete or insert at a lower offset or the same offset
+    // modifies the position where to apply the incoming edit from the server/device.
+    if (edit2EditorChangeOffsets[i] <= position) {
+      position += edit2EditorChangeInserts[i];
+      position -= edit2EditorChangeDeletes[i]
+    }
+    // Any offset higher than the current position gets modified accordingly.
+    // If inserting at the current position, increase that offset.
+    // If deleting at the current position, decrease that offset.
+    if (edit2EditorChangeOffsets[i] > position) {
+      if (ins_op) edit2EditorChangeOffsets[i] += size;
+      if (del_op) edit2EditorChangeOffsets[i] -= size;
+    }
+  }
+
+  return position
+}
+
+
+//
+//
+// Clipboard paste handling.
+//
+//
+
+
+// Pasting text into Quill has a few problems:
+// https://github.com/bibledit/cloud/issues/717
+// This paste handler aims to fix those.
+function ChapterEditorHandlePaste (e)
+{
+  // Stop data from actually being pasted.
+  e.stopPropagation();
+  e.preventDefault();
+
+  // Get the selected range, if any.
+  // If the editor was not focused, the range is not defined:
+  // Nothing more to do so bail out.
+  var range = quill.getSelection();
+  if (!range) return;
+  
+  // Unselect any selected text.
+  if (range.length != 0) {
+    quill.setSelection (range.index, range.length);
+  }
+
+  // Get pasted data via clipboard API.
+  var clipboardData = e.clipboardData || window.clipboardData;
+  var pastedData = clipboardData.getData('Text');
+
+  // Inserting the text from the clipboard immediately into the editor does not work.
+  // The work-around is to store data about where and what to paste.
+  // And then to do the actual insert after a very short delay.
+  pasteIndex = range.index;
+  pasteText = pastedData;
+  setTimeout (HandlePasteInsert, 10);
+}
+
+var pasteIndex = 0;
+var pasteText = "";
+
+
+function HandlePasteInsert()
+{
+  // Insert the text from the clipboard into the editor.
+  quill.insertText(pasteIndex, pasteText);
+}
