@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -47,15 +47,14 @@ string edit_preview_url ()
 bool edit_preview_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return read;
 }
 
 
 string edit_preview (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   bool touch = request->session_logic ()->touchEnabled ();
   bool timeout = request->query.count ("timeout");
@@ -75,7 +74,7 @@ string edit_preview (void * webserver_request)
   
   // Get active Bible, and check read access to it.
   // If needed, change Bible to one it has read access to.
-  string bible = access_bible_clamp (request, request->database_config_user()->getBible ());
+  string bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
   
   string cls = Filter_Css::getClass (bible);
   string font = Fonts_Logic::getTextFont (bible);
