@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_EDIT_SAVE_H
-#define INCLUDED_EDIT_SAVE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 string edit_save_url ();
 bool edit_save_acl (void * webserver_request);
 string edit_save (void * webserver_request);
-
-
-#endif
