@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -62,13 +62,6 @@ void Editor_Usfm2Html::stylesheet (string stylesheet)
 }
 
 
-// Enable styles suitable for Quill-based editor.
-void Editor_Usfm2Html::quill ()
-{
-  quill_enabled = true;
-}
-
-
 void Editor_Usfm2Html::run ()
 {
   preprocess ();
@@ -79,6 +72,8 @@ void Editor_Usfm2Html::run ()
 
 string Editor_Usfm2Html::get ()
 {
+  closeParagraph ();
+
   // If there are notes, move the notes <div> or <p> after everything else.
   // (It has the <hr> or <br> as a child).
   size_t count = distance (notes_node.begin (), notes_node.end ());
@@ -87,11 +82,9 @@ string Editor_Usfm2Html::get ()
   }
 
   // A Quill-based editor does not work with embedded <p> elements.
-  // Move the notes out of their parent and append them to the end main body.
-  if (quill_enabled) {
-    while (xml_node note = notes_node.first_child ().next_sibling ()) {
-      body_node.append_move (note);
-    }
+  // Move the notes out of their parent and append them to the end of the main body.
+  while (xml_node note = notes_node.first_child ().next_sibling ()) {
+    body_node.append_move (note);
   }
   
   // Get the html code, including body, without head.
@@ -108,20 +101,6 @@ string Editor_Usfm2Html::get ()
       html.erase  (pos);
     }
   }
-
-  // Deal with a blank line.
-  // The \b in USFM, a blank line, gets converted to:
-  // <p class="b" />
-  // But this does not display a blank in the web browser.
-  // Therefore convert it to the following:
-  // <p class="b"><br></p>
-  // This is how the webkit browser naturally represents a new empty line.
-  // Also do the other markers similar to the blank line.
-  vector <string> blank_lines = { "b", "sd", "sd1", "sd2", "sd3", "sd4" };
-  for (auto clas : blank_lines) {
-    if (quill_enabled) clas.insert (0, quill_logic_class_prefix_block ());
-    html = filter_string_str_replace ("<p class=\"" + clas + "\" />", "<p class=\"" + clas + "\"><br></p>", html);
-  }
   
   // Currently the XML library produces hexadecimal character entities.
   // This is unwanted behaviour: Convert them to normal characters.
@@ -140,7 +119,7 @@ void Editor_Usfm2Html::preprocess ()
   noteCount = 0;
   currentNoteTextStyles.clear();
   textLength = 0;
-  verseStartOffsets = { make_pair (0, 0) };
+  verseStartOffsets = { pair (0, 0) };
   current_p_open = false;
   note_p_open = false;
 
@@ -153,23 +132,17 @@ void Editor_Usfm2Html::preprocess ()
   // It comes at the start of the document.
   // (Later, it will either be deleted, or moved to the end).
   string notes_value = "notes";
-  if (quill_enabled) {
-    notes_node = document.append_child ("p");
-    notes_value.insert (0, quill_logic_class_prefix_block ());
-    notes_node.append_attribute ("class") = notes_value.c_str ();
-    notes_node.append_child ("br");
-  } else {
-    notes_node = document.append_child ("div");
-    notes_node.append_attribute ("id") = notes_value.c_str ();
-    notes_node.append_child ("hr");
-  }
+  notes_node = document.append_child ("p");
+  notes_value.insert (0, quill_logic_class_prefix_block ());
+  notes_node.append_attribute ("class") = notes_value.c_str ();
+  notes_node.text().set(non_breaking_space_u00A0().c_str());
 }
 
- 
+
 void Editor_Usfm2Html::process ()
 {
   markersAndTextPointer = 0;
-  unsigned int markersAndTextCount = markersAndText.size();
+  size_t markersAndTextCount = markersAndText.size();
   for (markersAndTextPointer = 0; markersAndTextPointer < markersAndTextCount; markersAndTextPointer++) {
     string currentItem = markersAndText[markersAndTextPointer];
     if (usfm_is_usfm_marker (currentItem))
@@ -210,6 +183,7 @@ void Editor_Usfm2Html::process ()
           case StyleTypeStartsParagraph:
           {
             closeTextStyle (false);
+            closeParagraph ();
             newParagraph (marker);
             break;
           }
@@ -230,6 +204,7 @@ void Editor_Usfm2Html::process ()
           case StyleTypeChapterNumber:
           {
             closeTextStyle (false);
+            closeParagraph ();
             newParagraph (marker);
             break;
           }
@@ -245,7 +220,7 @@ void Editor_Usfm2Html::process ()
             openTextStyle (style, false);
             string textFollowingMarker = usfm_get_text_following_marker (markersAndText, markersAndTextPointer);
             string number = usfm_peek_verse_number (textFollowingMarker);
-            verseStartOffsets [convert_to_int (number)] = textLength;
+            verseStartOffsets [convert_to_int (number)] = static_cast<int>(textLength);
             addText (number);
             closeTextStyle (false);
             addText (" ");
@@ -418,6 +393,7 @@ void Editor_Usfm2Html::outputAsIs (string marker, bool isOpeningMarker)
   // Output the marker in monospace font.
   if (isOpeningMarker) {
     // Add opening marker as it is.
+    closeParagraph ();
     newParagraph ("mono");
     addText (usfm_get_opening_usfm (marker));
   } else {
@@ -429,24 +405,38 @@ void Editor_Usfm2Html::outputAsIs (string marker, bool isOpeningMarker)
 
 void Editor_Usfm2Html::newParagraph (string style)
 {
-  currentPnode = body_node.append_child ("p");
+  // Handle new paragraph.
+  current_p_node = body_node.append_child ("p");
   current_p_open = true;
   if (!style.empty()) {
     string style2 (style);
-    if (quill_enabled) style2.insert (0, quill_logic_class_prefix_block ());
-    currentPnode.append_attribute ("class") = style2.c_str();
+    style2.insert (0, quill_logic_class_prefix_block ());
+    current_p_node.append_attribute ("class") = style2.c_str();
   }
   currentParagraphStyle = style;
   currentParagraphContent.clear();
   // A Quill-based editor assigns a length of one to a new line.
-  if (quill_enabled) {
-    // Skip the first line.
-    if (first_line_done) textLength++;
-  }
+  // Skip the first line.
+  if (first_line_done) textLength++;
   first_line_done = true;
 }
 
 
+void Editor_Usfm2Html::closeParagraph ()
+{
+  // Deal with a blank line.
+  // If the paragraph is empty, add a <br> to it.
+  // This is how the Quill editor naturally represents a new empty line.
+  // This causes that empty paragraph to be displayed properly in the Quill editor.
+  // This <br> is also needed for live editor updates.
+  if (current_p_open) {
+    if (currentParagraphContent.empty()) {
+      current_p_node.append_child("br");
+    }
+  }
+}
+
+
 // This opens a text style.
 // $style: the array containing the style variables.
 // $embed: boolean: Whether to open embedded / nested style.
@@ -485,7 +475,7 @@ void Editor_Usfm2Html::addText (string text)
     if (!current_p_open) {
       newParagraph ();
     }
-    xml_node spanDomElement = currentPnode.append_child ("span");
+    xml_node spanDomElement = current_p_node.append_child ("span");
     spanDomElement.text ().set (text.c_str());
     if (!currentTextStyles.empty ()) {
       // Take character style(s) as specified in this object.
@@ -498,12 +488,11 @@ void Editor_Usfm2Html::addText (string text)
           // That causes the whole class to be removed.
           // Right now the way to deal with a class with two styles is like this "i-add0nd".
           // It has one hyphen. And a "0" to separate the two styles.
-          if (quill_enabled) textstyle.append ("0");
-          else textstyle.append (" ");
+          textstyle.append ("0");
         }
         textstyle.append (style);
       }
-      if (quill_enabled) textstyle.insert (0, quill_logic_class_prefix_inline ());
+      textstyle.insert (0, quill_logic_class_prefix_inline ());
       spanDomElement.append_attribute ("class") = textstyle.c_str();
     }
     currentParagraphContent.append (text);
@@ -516,7 +505,7 @@ void Editor_Usfm2Html::addText (string text)
 // $citation: The text of the note citation.
 // $style: Style name for the paragraph in the note body.
 // $endnote: Whether this is a footnote and cross reference (false), or an endnote (true).
-void Editor_Usfm2Html::addNote (string citation, string style, bool endnote)
+void Editor_Usfm2Html::addNote (string citation, string style, [[maybe_unused]] bool endnote)
 {
   // Be sure the road ahead is clear.
   if (!roadIsClear ()) {
@@ -529,38 +518,23 @@ void Editor_Usfm2Html::addNote (string citation, string style, bool endnote)
     newParagraph ();
   }
   
-  // Not used:
-  (void) endnote;
-  
   noteCount++;
   noteOpened = true;
   
   // Add the link with all relevant data for the note citation.
-  if (quill_enabled) {
-    addNoteQuillLink (currentPnode, noteCount, "call", citation);
-  } else {
-    string reference = "#note" + convert_to_string (noteCount);
-    string identifier = "citation" + convert_to_string (noteCount);
-    addNoteDomLink (currentPnode, reference, identifier, "superscript", citation);
-  }
+  addNotelLink (current_p_node, noteCount, "call", citation);
   
   // Open a paragraph element for the note body.
   notePnode = notes_node.append_child ("p");
   note_p_open = true;
   string cls (style);
-  if (quill_enabled) cls.insert (0, quill_logic_class_prefix_block ());
+  cls.insert (0, quill_logic_class_prefix_block ());
   notePnode.append_attribute ("class") = cls.c_str();
   
   closeTextStyle (false);
   
   // Add the link with all relevant data for the note body.
-  if (quill_enabled) {
-    addNoteQuillLink (notePnode, noteCount, "body", citation);
-  } else {
-    string reference = "#citation" + convert_to_string (noteCount);
-    string identifier = "note" + convert_to_string (noteCount);
-    addNoteDomLink (notePnode, reference, identifier, "", citation);
-  }
+  addNotelLink (notePnode, noteCount, "body", citation);
   
   // Add a space.
   addNoteText (" ");
@@ -583,14 +557,8 @@ void Editor_Usfm2Html::addNoteText (string text)
   if (!currentNoteTextStyles.empty()) {
     // Take character style(s) as specified in this object.
     string classs;
-    if (quill_enabled) {
-      classs = filter_string_implode (currentNoteTextStyles, "0");
-    } else {
-      classs = filter_string_implode (currentNoteTextStyles, " ");
-    }
-    if (quill_enabled) {
-      classs.insert (0, quill_logic_class_prefix_inline ());
-    }
+    classs = filter_string_implode (currentNoteTextStyles, "0");
+    classs.insert (0, quill_logic_class_prefix_inline ());
     spanDomElement.append_attribute ("class") = classs.c_str();
   }
 }
@@ -606,38 +574,13 @@ void Editor_Usfm2Html::closeCurrentNote ()
 }
 
 
-// This adds a link as a mechanism to connect body text with a note body.
-// $domNode: The DOM node where to add the link to.
-// $reference: The link's href, e.g. where it links to.
-// $identifier: The link's identifier. Others can link to it.
-// $style: The link text's style.
-// $text: The link's text.
-// It also deals with a Quill-based editor, in a slightly different way.
-void Editor_Usfm2Html::addNoteDomLink (xml_node domNode, string reference, string identifier, string style, string text)
-{
-  xml_node aDomElement = domNode.append_child ("a");
-  aDomElement.append_attribute ("href") = reference.c_str();
-  aDomElement.append_attribute ("id") = identifier.c_str();
-  // The link itself, for the notes, is not editable, so it can be clicked.
-  // It was disabled again due to Chrome removing content on backspace.
-  // $aDomElement->setAttribute ("contenteditable", "false");
-  // Remove the blue color from the link, and the underline.
-  // The reason for this is that, if the blue and underline are there, people expect one can click on it.
-  // Clicking it does nothing. Therefore it's better to remove the typical link style.
-  aDomElement.append_attribute ("style") = "text-decoration:none; color: inherit;";
-  // Style = class.
-  if (style != "") aDomElement.append_attribute ("class") = style.c_str();
-  aDomElement.text ().set (text.c_str());
-}
-
-
 // This adds a link as a mechanism to connect body text with a note body.
 // $domNode: The DOM node where to add the link to.
 // $identifier: The link's identifier.
 // $style: A style for the note citation, and one for the note body.
 // $text: The link's text.
 // It also deals with a Quill-based editor, in a slightly different way.
-void Editor_Usfm2Html::addNoteQuillLink (xml_node domNode, int identifier, string style, string text)
+void Editor_Usfm2Html::addNotelLink (xml_node domNode, int identifier, string style, string text)
 {
   xml_node aDomElement = domNode.append_child ("span");
   string cls = "i-note" + style + convert_to_string (identifier);
@@ -678,7 +621,7 @@ bool Editor_Usfm2Html::roadIsClear ()
   bool end_chapter_reached = false;
   {
     bool done = false;
-    unsigned int markersAndTextCount = markersAndText.size();
+    size_t markersAndTextCount = markersAndText.size();
     for (size_t pointer = markersAndTextPointer + 1; pointer < markersAndTextCount; pointer++) {
       if (done) continue;
       string currentItem = markersAndText[pointer];
