@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -47,15 +47,14 @@ string editusfm_index_url ()
 bool editusfm_index_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return write;
 }
 
 
 string editusfm_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   
   bool touch = request->session_logic ()->touchEnabled ();
@@ -67,7 +66,7 @@ string editusfm_index (void * webserver_request)
     int book = convert_to_int (switchbook);
     int chapter = convert_to_int (switchchapter);
     Ipc_Focus::set (request, book, chapter, 1);
-    Navigation_Passage::recordHistory (request, book, chapter, 1);
+    Navigation_Passage::record_history (request, book, chapter, 1);
   }
   
   
@@ -84,7 +83,7 @@ string editusfm_index (void * webserver_request)
     string changebible = request->query["changebible"];
     if (changebible == "") {
       Dialog_List dialog_list = Dialog_List ("index", translate("Select which Bible to open in the editor"), "", "");
-      vector <string> bibles = access_bible_bibles (request);
+      vector <string> bibles = AccessBible::Bibles (request);
       for (auto & bible : bibles) {
         dialog_list.add_row (bible, "changebible", bible);
       }
@@ -101,8 +100,8 @@ string editusfm_index (void * webserver_request)
 
   // Get active Bible, and check read access to it.
   // If needed, change Bible to one it has read access to.
-  string bible = access_bible_clamp (request, request->database_config_user()->getBible ());
-  if (request->query.count ("bible")) bible = access_bible_clamp (request, request->query ["bible"]);
+  string bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
+  if (request->query.count ("bible")) bible = AccessBible::Clamp (request, request->query ["bible"]);
   view.set_variable ("bible", bible);
   
   
@@ -111,24 +110,28 @@ string editusfm_index (void * webserver_request)
   
   
   int verticalCaretPosition = request->database_config_user ()->getVerticalCaretPosition ();
-  string script =
-  "var usfmEditorChapterLoaded = \"" + locale_logic_text_loaded () + "\";\n"
-  "var usfmEditorWillSave = \"" + locale_logic_text_will_save () + "\";\n"
-  "var usfmEditorChapterSaving = \"" + locale_logic_text_saving () + "\";\n"
-  "var usfmEditorChapterSaved = \"" + locale_logic_text_saved () + "\";\n"
-  "var usfmEditorChapterRetrying = \"" + locale_logic_text_retrying () + "\";\n"
-  "var usfmEditorVerseUpdatedLoaded = '" + locale_logic_text_reload () + "';\n"
-  "var usfmEditorWriteAccess = true;\n"
-  "var verticalCaretPosition = " + convert_to_string (verticalCaretPosition) + ";\n";
+  stringstream ss;
+  ss << "var usfmEditorChapterLoaded = " << quoted(locale_logic_text_loaded ()) << ";" << endl;
+  ss << "var usfmEditorWillSave = " << quoted(locale_logic_text_will_save ()) << ";" << endl;
+  ss << "var usfmEditorChapterSaving = " << quoted(locale_logic_text_saving ()) << ";" << endl;
+  ss << "var usfmEditorChapterSaved = " << quoted(locale_logic_text_saved ()) << ";" << endl;
+  ss << "var usfmEditorChapterRetrying = " << quoted(locale_logic_text_retrying ()) << ";" << endl;
+  ss << "var usfmEditorVerseUpdatedLoaded = " << quoted(locale_logic_text_reload ()) << ";" << endl;
+  ss << "var usfmEditorWriteAccess = true;" << endl;
+  ss << "var verticalCaretPosition = " << verticalCaretPosition << ";" << endl;
+  string script = ss.str();
   config_logic_swipe_enabled (webserver_request, script);
   view.set_variable ("script", script);
   
 
   string cls = Filter_Css::getClass (bible);
   string font = Fonts_Logic::getTextFont (bible);
+  int current_theme_index = convert_to_int(request->database_config_user ()->getCurrentTheme ());
   int direction = Database_Config_Bible::getTextDirection (bible);
   int lineheight = Database_Config_Bible::getLineHeight (bible);
   int letterspacing = Database_Config_Bible::getLetterSpacing (bible);
+  view.set_variable ("editor_theme_color", Filter_Css::theme_picker (current_theme_index, 2));
+  view.set_variable ("active_editor_theme_color", Filter_Css::theme_picker (current_theme_index, 3));
   view.set_variable ("custom_class", cls);
   view.set_variable ("custom_css", Filter_Css::getCss (cls,
                                                              Fonts_Logic::getFontPath (font),
@@ -140,6 +143,9 @@ string editusfm_index (void * webserver_request)
   if (request->database_config_user ()->getFastEditorSwitchingAvailable ()) {
     view.enable_zone ("fastswitcheditor");
   }
+  if (config_logic_indonesian_cloud_free ()) {
+    view.enable_zone ("fastswitcheditor");
+  }
 
   page += view.render ("editusfm", "index");
   
