@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -47,15 +47,14 @@ string editusfm_save_url ()
 bool editusfm_save_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] = AccessBible::Any (webserver_request);
   return read;
 }
 
 
 string editusfm_save (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   
   string bible = request->post["bible"];
@@ -70,20 +69,24 @@ string editusfm_save (void * webserver_request)
     if (Checksum_Logic::get (usfm) == checksum) {
       usfm = filter_url_tag_to_plus (usfm);
       usfm = filter_string_trim (usfm);
+      // Collapse multiple spaces in the USFM into one space.
+      // https://github.com/bibledit/cloud/issues/711
+      usfm = filter_string_collapse_whitespace(usfm);
       if (!usfm.empty ()) {
         if (unicode_string_is_valid (usfm)) {
           string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
           vector <BookChapterData> book_chapter_text = usfm_import (usfm, stylesheet);
-          for (BookChapterData & data : book_chapter_text) {
+          if (!book_chapter_text.empty()) {
+            BookChapterData data = book_chapter_text[0];
             int book_number = data.book;
             int chapter_number = data.chapter;
             string chapter_data_to_save = data.data;
             if (((book_number == book) || (book_number == 0)) && (chapter_number == chapter)) {
               // The USFM loaded into the editor.
-              string ancestor_usfm = getLoadedUsfm (webserver_request, bible, book, chapter, unique_id);
+              string ancestor_usfm = getLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
               // Collect some data about the changes for this user.
               string username = request->session_logic()->currentUser ();
-              int oldID = request->database_bibles()->getChapterId (bible, book, chapter);
+              [[maybe_unused]] int oldID = request->database_bibles()->getChapterId (bible, book, chapter);
               string oldText = ancestor_usfm;
               string newText = chapter_data_to_save;
               // Merge if the ancestor is there and differs from what's in the database.
@@ -99,6 +102,7 @@ string editusfm_save (void * webserver_request)
               }
               
               // Check on the merge.
+              filter_merge_add_book_chapter (conflicts, book, chapter);
               bible_logic_merge_irregularity_mail ({username}, conflicts);
               
               // If the USFM on disk is different from the USFM that was sent to the editor,
@@ -115,11 +119,11 @@ string editusfm_save (void * webserver_request)
               
              
               // Check on write access.
-              if (access_bible_book_write (request, "", bible, book)) {
+              if (AccessBible::BookWrite (request, string(), bible, book)) {
                 // Safely store the chapter.
                 string explanation;
                 string message = usfm_safely_store_chapter (request, bible, book, chapter, chapter_data_to_save, explanation);
-                bible_logic_unsafe_save_mail (message, explanation, username, chapter_data_to_save);
+                bible_logic_unsafe_save_mail (message, explanation, username, chapter_data_to_save, book, chapter);
                 if (message.empty()) {
 #ifndef HAVE_CLIENT
                   // Server configuration: Store details for the user's changes.
@@ -130,11 +134,9 @@ string editusfm_save (void * webserver_request)
                     Database_Git::store_chapter (username, bible, book, chapter, oldText, newText);
                   }
                   rss_logic_schedule_update (username, bible, book, chapter, oldText, newText);
-#else
-                  (void) oldID;
 #endif
                   // Store a copy of the USFM loaded in the editor for later reference.
-                  storeLoadedUsfm (webserver_request, bible, book, chapter, unique_id);
+                  storeLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
                   return locale_logic_text_saved ();
                 }
                 return message;
