@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -31,11 +31,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #ifdef HAVE_WINDOWS
 #include <windows.h>
 #endif
+#include <config/globals.h>
 
 
-void sigint_handler (int s)
+void sigint_handler ([[maybe_unused]] int s)
 {
-  (void) s;
   // When pressing Ctrl-C, the system outputs a "^C".
   // It is cleaner to write a new line after that.
   cout << endl;
@@ -46,7 +46,7 @@ void sigint_handler (int s)
 
 string backtrace_path ()
 {
-  string path = filter_url_create_root_path (filter_url_temp_dir (), "backtrace.txt");
+  string path = filter_url_create_root_path ({filter_url_temp_dir (), "backtrace.txt"});
   return path;
 }
 
@@ -54,15 +54,13 @@ string backtrace_path ()
 #ifdef HAVE_EXECINFO
 // http://stackoverflow.com/questions/77005/how-to-generate-a-stacktrace-when-my-gcc-c-app-crashes
 // To add linker flag -rdynamic is essential.
-void sigsegv_handler (int sig)
+void sigsegv_handler ([[maybe_unused]] int sig)
 {
-  (void) sig;
-
   // Information.
   cout << "Segmentation fault, writing backtrace to " << backtrace_path () << endl;
 
   void *array[20];
-  size_t size;
+  int size;
   
   // Get void*'s for all entries on the stack
   size = backtrace (array, 20);
@@ -90,12 +88,8 @@ void my_invalid_parameter_handler(const wchar_t* expression, const wchar_t* func
 #endif
 
 
-int main (int argc, char **argv)
+int main ([[maybe_unused]] int argc, [[maybe_unused]] char **argv)
 {
-  (void) argc;
-  (void) argv;
-
-  
   // Ctrl-C initiates a clean shutdown sequence, so there's no memory leak.
   signal (SIGINT, sigint_handler);
 
@@ -121,8 +115,7 @@ int main (int argc, char **argv)
     // The following works on Linux but not on macOS:
     char *linkname = (char *) malloc (256);
     memset (linkname, 0, 256); // valgrind uninitialized value(s)
-    ssize_t r = readlink ("/proc/self/exe", linkname, 256);
-    (void) r;
+    [[maybe_unused]] ssize_t result = readlink ("/proc/self/exe", linkname, 256);
     webroot = filter_url_dirname (linkname);
     free (linkname);
   }
@@ -176,26 +169,29 @@ int main (int argc, char **argv)
       // because it now runs the binary installed in /usr/bin.
       if ((webroot == homefolder) || (webroot.find (PACKAGE_PREFIX_DIR) == 0)) {
         // Update web root to ~/bibledit or ~/bibledit-cloud.
-        webroot = filter_url_create_path (homefolder, filter_url_basename (PACKAGE_DATA_DIR));
+        webroot = filter_url_create_path ({homefolder, filter_url_basename (PACKAGE_DATA_DIR)});
       }
     }
   }
 #endif
-  // The $make install will copy the data files to /usr/share/bibledit.
+  // The $ make install will copy the data files to /usr/share/bibledit.
   // That is the package data directory.
   // Bibledit will copy this to the webroot upon first run for a certain version number.
   // If this directory is empty, it won't copy anything.
   // That would be okay if it runs in a user folder like ~/bibledit or similar.
   // Read the package directory from config.h.
   bibledit_initialize_library (PACKAGE_DATA_DIR, webroot.c_str());
-
   
+
   // Start the Bibledit library.
   bibledit_start_library ();
   bibledit_log ("The server started");
   cout << "Listening on http://localhost:" << config_logic_http_network_port ();
 #ifdef HAVE_CLOUD
-  cout << " and https://localhost:" << config_logic_https_network_port ();
+  string https_port = config_logic_https_network_port ();
+  if (https_port.length() > 1) {
+    cout << " and https://localhost:" << https_port;
+  }
 #endif
   cout << endl;
   cout << "Press Ctrl-C to quit" << endl;
@@ -209,6 +205,8 @@ int main (int argc, char **argv)
     vector <string> lines = filter_string_explode (backtrace, '\n');
     for (auto & line : lines) {
       Database_Logs::log (line);
+      // Set a flag if the backtrace appears to be caused while sending email.
+      if (line.find ("email_send") != string::npos) config_globals_has_crashed_while_mailing = true;
     }
   }
 
