@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,15 +17,9 @@
  */
 
 
-#ifndef INCLUDED_EXPORT_WEB_H
-#define INCLUDED_EXPORT_WEB_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 void export_web_book (string bible, int book, bool log);
 void export_web_index (string bible, bool log);
-
-
-#endif
