@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@
  */
 
 
-#ifndef INCLUDED_FILTER_CUSTOMCSS_H
-#define INCLUDED_FILTER_CUSTOMCSS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Filter_Css
 {
 public:
@@ -45,10 +42,13 @@ public:
   static int writingModeValue (string mode);
   static string getClass (string bible);
   static string getCss (string class_, string font, int directionvalue, int lineheight = 100, int letterspacing = 0);
+  static void distinction_set_basic ();
+  static string distinction_set_light (int itemstyleindex);
+  static string distinction_set_dark (int itemstyleindex);
+  static string distinction_set_redblue_light (int itemstyleindex);
+  static string distinction_set_redblue_dark (int itemstyleindex);
+  static string distinction_set_notes (int itemstyleindex);
+  static string theme_picker (int themestyleindex, int itemstyleindex);
 };
 
-
 string filter_css_grey_background ();
-
-
-#endif
