@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,9 @@ using dtl::Diff3;
 using namespace pugi;
 
 
+static mutex filter_merge_mutex;
+
+
 // This uses the dtl:: library for merge in C++.
 // At times the library failed to merge.
 // It was tried whether the Linux "merge" command was able to successfully merge such cases.
@@ -42,16 +45,21 @@ using namespace pugi;
 // If case of conflicts, it returns an empty container.
 vector <string> filter_merge_merge (const vector <string>& base, const vector <string>& user, const vector <string>& server)
 {
-  typedef string elem;
-  typedef vector <string> sequence;
+  // See issue https://github.com/bibledit/cloud/issues/418
+  // It is unclear at this time whether the code below
+  // to find the differences between texts, is thread-safe.
+  // So just to be sure, a mutex is placed around it.
+  filter_merge_mutex.lock();
 
-  sequence A (user);
-  sequence B (base);
-  sequence C (server);
+  vector <string> user_sequence (user);
+  vector <string> base_sequence (base);
+  vector <string> server_sequence (server);
 
-  Diff3 <elem, sequence> diff3 (A, B, C);
+  Diff3 <string, vector <string>> diff3 (user_sequence, base_sequence, server_sequence);
   diff3.compose ();
-  if (!diff3.merge ()) {
+  bool merged = diff3.merge ();
+  filter_merge_mutex.unlock();
+  if (!merged) {
     return {};
   }
   return diff3.getMergedSequence ();
@@ -138,11 +146,11 @@ void filter_merge_detect_conflict (string base, string change, string prioritize
   
   if (!irregularity) {
     if ((change != base) && (prioritized_change != change) && (prioritized_change == result)) {
-      subject = "Failed to merge: The existing text was kept";
+      subject = "Failed to merge your changes";
       irregularity = true;
     }
   }
-  
+
   if (irregularity) {
     Merge_Conflict conflict;
     conflict.base = base;
@@ -285,3 +293,12 @@ string filter_merge_run_clever (string base, string change, string prioritized_c
   // Done.
   return filter_string_implode (results, "\n");
 }
+
+
+void filter_merge_add_book_chapter (vector <Merge_Conflict> & conflicts, int book, int chapter)
+{
+  for (auto & conflict : conflicts) {
+    conflict.book = book;
+    conflict.chapter = chapter;
+  }
+}
