@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,14 +17,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_FILTER_STRING_H
-#define INCLUDED_FILTER_STRING_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/string.hpp>
 
-
 vector <string> filter_string_explode (string value, char delimiter);
 vector <string> filter_string_explode (string value, string delimiters);
 string filter_string_implode (vector <string>& values, string delimiter);
@@ -72,12 +69,16 @@ bool unicode_string_is_valid (string s);
 bool unicode_string_is_punctuation (string s);
 int unicode_string_convert_to_codepoint (string s);
 string unicode_string_str_replace (string search, string replace, string subject);
+#ifdef HAVE_ICU
+string icu_string_normalize (string s, bool remove_diacritics, bool casefold);
+#endif
 int filter_string_rand (int floor, int ceiling);
 string filter_string_html2text (string html);
 string filter_string_extract_email (string input);
 string filter_string_extract_body (string input, string year = "", string sender = "");
 string get_checkbox_status (bool enabled);
-string get_disabled (bool disabled);
+string get_disabled (bool disabled = true);
+string get_reload ();
 void quick_sort (vector <unsigned int>& one, vector <string>& two, unsigned int beg, unsigned int end);
 void quick_sort (vector <string>& one, vector <unsigned int>& two, unsigned int beg, unsigned int end);
 void quick_sort (vector <unsigned int>& one, vector <unsigned int>& two, unsigned int beg, unsigned int end);
@@ -120,6 +121,5 @@ string wstring2string (const wstring& wstr);
 string lf2crlf (string str);
 string crlf2lf (string str);
 string filter_text_html_get_element (string html, string element);
-
-
-#endif
+string filter_string_tidy_invalid_html (string html);
+string filter_string_collapse_whitespace (string s);
