@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,14 +17,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_HTML_HEADER_H
-#define INCLUDED_HTML_HEADER_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <database/styles.h>
 
-
 class Html_Header
 {
 public:
@@ -36,7 +33,3 @@ private:
   string searchBackLinkUrl;
   string searchBackLinkText;
 };
-
-
-#endif
-
