@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_INDEX_LISTING_H
-#define INCLUDED_INDEX_LISTING_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 string index_listing_url (string url);
 bool index_listing_acl (void * webserver_request, string url);
 string index_listing (void * webserver_request, string url);
-
-
-#endif
