@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,18 +17,10 @@
  */
 
 
-#ifndef INCLUDED_JOURNAL_LOGIC_H
-#define INCLUDED_JOURNAL_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 bool journal_logic_filter_entry (const string& entry);
 string journal_logic_filtered_message ();
 string journal_logic_see_journal_for_progress ();
-void journal_logic_log_incoming_connection (void * webserver_request);
-void journal_logic_log_incoming_connections ();
-
-
-#endif
