@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,20 +17,15 @@
  */
 
 
-#ifndef INCLUDED_WEBSERVER_LOCKS_H
-#define INCLUDED_WEBSERVER_LOCKS_H
-
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-  void thread_setup ();
-  void thread_cleanup ();
+  void thread_setup (void);
+  void thread_cleanup (void);
   
 #ifdef __cplusplus
 }
 #endif
-
-
-#endif
