@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,15 +25,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <config/globals.h>
 
 
-// Filters out the default language.
-// Returns the $localization, or "" in case of the default language.
-string locale_logic_filter_default_language (string localization)
-{
-  if (localization == "default") localization.clear ();
-  return localization;
-}
-
-
 // Takes a month from 1 to 12, and returns its localized name.
 string locale_logic_month (int month)
 {
@@ -86,14 +77,14 @@ string locale_logic_date_time (int seconds)
 // Return the available localizations.
 map <string, string> locale_logic_localizations ()
 {
-  string directory = filter_url_create_root_path ("locale");
+  string directory = filter_url_create_root_path ({"locale"});
   vector <string> files = filter_url_scandir (directory);
-  map <string, string> localizations = {make_pair ("", english ())};
+  map <string, string> localizations = {pair ("", english ())};
   for (auto file : files) {
     string suffix = filter_url_get_extension (file);
     if (suffix == "po") {
       string basename = filter_string_str_replace ("." + suffix, "", file);
-      string path = filter_url_create_path (directory, file);
+      string path = filter_url_create_path ({directory, file});
       string contents = filter_url_file_get_contents (path);
       string language = translate ("Unknown");
       vector <string> lines = filter_string_explode (contents, '\n');
@@ -104,7 +95,7 @@ map <string, string> locale_logic_localizations ()
           language = line;
         }
       }
-      localizations.insert (make_pair (basename, language));
+      localizations.insert (pair (basename, language));
     }
   }
   return localizations;
@@ -176,6 +167,18 @@ string locale_logic_text_will_save ()
 }
 
 
+string locale_logic_text_updating ()
+{
+  return translate ("Updating...");
+}
+
+
+string locale_logic_text_updated ()
+{
+  return translate ("Updated");
+}
+
+
 string locale_logic_text_saving ()
 {
   return translate ("Saving...");
@@ -210,10 +213,6 @@ string locale_logic_text_reload ()
 {
   string message;
   message.append (translate("Updated Bible text was loaded."));
-  message.append (" ");
-  message.append (translate("Press Enter to continue."));
-  message.append (" ");
-  message.append (translate("Please check the updated text."));
   return message;
 }
 
@@ -275,7 +274,7 @@ bool locale_logic_obfuscate_compare_internal (const string& a, const string& b)
 void locale_logic_obfuscate_initialize ()
 {
   // Load the contents of the obfuscation configuration file
-  string filename = filter_url_create_root_path ("obfuscate", "texts.txt");
+  string filename = filter_url_create_root_path ({"obfuscate", "texts.txt"});
   string contents = filter_url_file_get_contents (filename);
   vector <string> lines = filter_string_explode (contents, '\n');
   
