@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/roles.h>
 #include <filter/url.h>
 #include <filter/string.h>
+#include <filter/date.h>
 #include <tasks/logic.h>
 #include <webserver/request.h>
 #include <journal/index.h>
@@ -40,6 +41,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <menu/logic.h>
 #include <session/switch.h>
 #include <ldap/logic.h>
+#include <user/logic.h>
 
 
 string manage_users_url ()
@@ -56,7 +58,7 @@ bool manage_users_acl (void * webserver_request)
 
 string manage_users (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   
   bool user_updated = false;
@@ -87,6 +89,7 @@ string manage_users (void * webserver_request)
       page += Assets_Page::error (translate("User already exists"));
     } else {
       request->database_users ()->add_user(user, user, Filter_Roles::member (), "");
+      user_logic_store_account_creation (user);
       user_updated = true;
       page += Assets_Page::success (translate("User created"));
     }
@@ -102,35 +105,19 @@ string manage_users (void * webserver_request)
   if (request->query.count ("delete")) {
     string role = Filter_Roles::text (objectUserLevel);
     string email = request->database_users ()->get_email (objectUsername);
-    vector <string> users = request->database_users ()->getUsers ();
+    vector <string> users = request->database_users ()->get_users ();
     vector <string> administrators = request->database_users ()->getAdministrators ();
     if (users.size () == 1) {
       page += Assets_Page::error (translate("Cannot remove the last user"));
     } else if ((objectUserLevel >= Filter_Roles::admin ()) && (administrators.size () == 1)) {
       page += Assets_Page::error (translate("Cannot remove the last administrator"));
+    } else if (config_logic_demo_enabled () && (objectUsername ==  session_admin_credentials ())) {
+      page += Assets_Page::error (translate("Cannot remove the demo admin"));
     } else {
-      string message = "Deleted user " + objectUsername + " with role " + role + " and email " + email;
-      Database_Logs::log (message, Filter_Roles::admin ());
-      request->database_users ()->removeUser (objectUsername);
+      string message;
+      user_logic_delete_account (objectUsername, role, email, message);
       user_updated = true;
-      database_privileges_client_remove (objectUsername);
       page += Assets_Page::success (message);
-      // Also remove any privileges for this user.
-      // In particular for the Bible privileges this is necessary,
-      // beause if old users remain in the privileges storage,
-      // then a situation where no user has any privileges to any Bible,
-      // and thus all relevant users have all privileges,
-      // can never be achieved again.
-      Database_Privileges::removeUser (objectUsername);
-      // Remove any login tokens the user might have had: Just to clean things up.
-      Database_Login::removeTokens (objectUsername);
-      // Remove any settings for the user.
-      // The advantage of this is that when a user is removed, all settings are gone,
-      // so when the same user would be created again, all settings will go back to their defaults.
-      request->database_config_user ()->remove (objectUsername);
-      // Remove note assignments for clients for this user.
-      Database_NoteAssignment database_noteassignment;
-      database_noteassignment.remove (objectUsername);
     }
   }
   
@@ -239,7 +226,7 @@ string manage_users (void * webserver_request)
   
   
   // User accounts to display.
-  vector <string> tbody;
+  stringstream tbody;
   bool ldap_on = ldap_logic_is_on ();
   // Retrieve assigned users.
   vector <string> users = access_user_assignees (webserver_request);
@@ -253,127 +240,130 @@ string manage_users (void * webserver_request)
     bool enabled = request->database_users ()->get_enabled (username);
     
     // New row in table.
-    tbody.push_back ("<tr>");
+    tbody << "<tr>";
     
     // Display emoji to delete this account.
-    tbody.push_back ("<td>");
-    tbody.push_back ("<a href=\"?user=" + username + "&delete\">" + emoji_wastebasket () + "</a> " + username);
-    tbody.push_back ("</td>");
+    tbody << "<td>";
+    tbody << "<a href=" << quoted("?user=" + username + "&delete") << ">" << emoji_wastebasket () << "</a> " << username;
+    tbody << "</td>";
 
     // Divider.
-    tbody.push_back ("<td>│</td>");
+    tbody << "<td>│</td>";
     
     // The user's role is displayed when the account is enabled.
     // Normally the role can be changed, but when an LDAP server is enabled, it cannot be changed here.
-    tbody.push_back ("<td>");
+    tbody << "<td>";
     if (enabled) {
-      if (!ldap_on) tbody.push_back ("<a href=\"?user=" + username + "&level\">");
-      tbody.push_back (namedrole + "</a>");
-      if (!ldap_on) tbody.push_back ("</a>");
+      if (!ldap_on) tbody << "<a href=" << quoted ("?user=" + username + "&level") << ">";
+      tbody << namedrole << "</a>";
+      if (!ldap_on) tbody << "</a>";
     }
-    tbody.push_back ("</td>");
+    tbody << "</td>";
     
     // Divider.
-    tbody.push_back ("<td>│</td>");
+    tbody << "<td>│</td>";
     
     // The user's email address will be displayed when the account is enabled.
     // Normally the email address can be changed here,
     // but in case of authentication via an LDAP server, it cannot be changed here.
-    tbody.push_back ("<td>");
+    tbody << "<td>";
     if (enabled) {
-      if (!ldap_on) tbody.push_back ("<a href=\"?user=" + username + "&email\">");
-      tbody.push_back (email);
-      if (!ldap_on) tbody.push_back ("</a>");
+      if (!ldap_on) tbody << "<a href=" << quoted ("?user=" + username + "&email") << ">";
+      tbody << email;
+      if (!ldap_on) tbody << "</a>";
     }
-    tbody.push_back ("</td>");
+    tbody << "</td>";
     
     // Divider.
-    tbody.push_back ("<td>│</td>");
+    tbody << "<td>│</td>";
     
     // Assigned Bibles.
-    tbody.push_back ("<td>");
+    tbody << "<td>";
     if (enabled) {
       if (objectUserLevel < Filter_Roles::manager ()) {
         for (auto & bible : allbibles) {
           bool exists = Database_Privileges::getBibleBookExists (username, bible, 0);
           if (exists) {
-            bool read, write;
-            Database_Privileges::getBible (username, bible, read, write);
+            auto [ read, write ] = Database_Privileges::getBible (username, bible);
             if  (objectUserLevel >= Filter_Roles::translator ()) write = true;
-            tbody.push_back ("<a href=\"?user=" + username + "&removebible=" + bible + "\">" + emoji_wastebasket () + "</a>");
-            tbody.push_back ("<a href=\"/bible/settings?bible=" + bible + "\">" + bible + "</a>");
-            tbody.push_back ("<a href=\"write?user=" + username + "&bible=" + bible + "\">");
+            tbody << "<a href=" << quoted ("?user=" + username + "&removebible=" + bible) << ">" << emoji_wastebasket () << "</a>";
+            tbody << "<a href=" << quoted("/bible/settings?bible=" + bible) << ">" << bible << "</a>";
+            tbody << "<a href=" << quoted("write?user=" + username + "&bible=" + bible) << ">";
             int readwritebooks = 0;
             vector <int> books = request->database_bibles ()->getBooks (bible);
             for (auto book : books) {
               Database_Privileges::getBibleBook (username, bible, book, read, write);
               if (write) readwritebooks++;
             }
-            tbody.push_back ("(" + convert_to_string (readwritebooks) + "/" + convert_to_string (books.size ()) + ")");
-            tbody.push_back ("</a>");
-            tbody.push_back ("|");
+            tbody << "(" << readwritebooks << "/" << books.size () << ")";
+            tbody << "</a>";
+            tbody << "|";
           }
         }
       }
       if (objectUserLevel >= Filter_Roles::manager ()) {
         // Managers and higher roles have access to all Bibles.
-        tbody.push_back ("(" + translate ("all") + ")");
+        tbody << "(" << translate ("all") << ")";
       } else {
-        tbody.push_back ("<a href=\"?user=" + username + "&addbible=\">" + emoji_heavy_plus_sign () + "</a>");
+        tbody << "<a href=" << quoted("?user=" + username + "&addbible=") << ">" << emoji_heavy_plus_sign () << "</a>";
       }
     }
-    tbody.push_back ("</td>");
+    tbody << "</td>";
 
     // Divider.
-    tbody.push_back ("<td>│</td>");
+    tbody << "<td>│</td>";
 
     // Assigned privileges to the user.
-    tbody.push_back ("<td>");
+    tbody << "<td>";
     if (enabled) {
       if (objectUserLevel >= Filter_Roles::manager ()) {
         // Managers and higher roles have all privileges.
-        tbody.push_back ("(" + translate ("all") + ")");
+        tbody << "(" << translate ("all") << ")";
       } else {
-        tbody.push_back ("<a href=\"privileges?user=" + username + "\">" + translate ("edit") + "</a>");
+        tbody << "<a href=" << quoted("privileges?user=" + username) << ">" << translate ("edit") << "</a>";
       }
     }
-    tbody.push_back ("</td>");
+    tbody << "</td>";
     
     // Disable or enable the account.
     if (myLevel >= Filter_Roles::manager ()) {
       if (myLevel > objectUserLevel) {
-        tbody.push_back ("<td>│</td>");
-        tbody.push_back ("<td>");
+        tbody << "<td>│</td>";
+        tbody << "<td>";
         bool enabled = request->database_users ()->get_enabled (username);
         if (enabled) {
-          tbody.push_back ("<a href=\"?user=" + username + "&disable\">" + translate ("Disable") + "</a>");
+          tbody << "<a href=" << quoted("?user=" + username + "&disable") << ">" << translate ("Disable") << "</a>";
         } else {
-          tbody.push_back ("<a href=\"?user=" + username + "&enable\">" + translate ("Enable") + "</a>");
+          tbody << "<a href=" << quoted("?user=" + username + "&enable") << ">" << translate ("Enable") << "</a>";
         }
-        tbody.push_back ("</td>");
+        tbody << "</td>";
       }
     }
 
     // Login on behalf of another user.
     if (enabled) {
       if (myLevel > objectUserLevel) {
-        tbody.push_back ("<td>│</td>");
-        tbody.push_back ("<td>");
-        tbody.push_back ("<a href=\"?user=" + username + "&login\">" + translate ("Login") + "</a>");
-        tbody.push_back ("</td>");
+        tbody << "<td>│</td>";
+        tbody << "<td>";
+        tbody << "<a href=" << quoted ("?user=" + username + "&login") << ">" << translate ("Login") << "</a>";
+        tbody << "</td>";
       }
     }
     
     // Done with the row.
-    tbody.push_back ("</tr>");
+    tbody << "</tr>";
   }
 
-  view.set_variable ("tbody", filter_string_implode (tbody, "\n"));
+  view.set_variable ("tbody", tbody.str());
 
   if (!ldap_on) {
     view.enable_zone ("local");
   }
-  
+
+  if (config_logic_indonesian_cloud_free ()) {
+    view.enable_zone("accounts");
+  }
+
   page += view.render ("manage", "users");
 
   page += Assets_Page::footer ();
