@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_MANAGE_USERS_H
-#define INCLUDED_MANAGE_USERS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 string manage_users_url ();
 bool manage_users_acl (void * webserver_request);
 string manage_users (void * webserver_request);
-
-
-#endif
