@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ bool notes_assign_1_acl (void * webserver_request)
 
 string notes_assign_1 (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
   Database_NoteAssignment database_noteassignment;
@@ -80,12 +80,12 @@ string notes_assign_1 (void * webserver_request)
 
 
   // Note assignees.
-  string userblock;
+  stringstream userblock;
   vector <string> assignees = database_noteassignment.assignees (user);
   for (auto & assignee : assignees) {
-    userblock.append ("<li><a href=\"assign-1?id=" + convert_to_string (id) + "&assign=" + assignee + "\">" + assignee + "</a></li>\n");
+    userblock << "<li><a href=" << quoted ("assign-1?id=" + convert_to_string (id) + "&assign=" + assignee) << ">" << assignee << "</a></li>" << endl;
   }
-  view.set_variable ("userblock", userblock);
+  view.set_variable ("userblock", userblock.str());
   
   
   view.set_variable ("success", success);
