@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ bool notes_bible_n_acl (void * webserver_request)
 
 string notes_bible_n (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
 
@@ -59,13 +59,13 @@ string notes_bible_n (void * webserver_request)
   Assets_View view;
   
   
-  string bibleblock;
-  vector <string> bibles = access_bible_bibles (webserver_request);
+  stringstream bibleblock;
+  vector <string> bibles = AccessBible::Bibles (webserver_request);
   bibles.push_back (notes_logic.generalBibleName ());
   for (auto & bible : bibles) {
-    bibleblock.append ("<li><a href=\"bulk?bible=" + bible + "\">" + bible + "</a></li>\n");
+    bibleblock << "<li><a href=" << quoted("bulk?bible=" + bible) << ">" << bible << "</a></li>" << endl;
   }
-  view.set_variable ("bibleblock", bibleblock);
+  view.set_variable ("bibleblock", bibleblock.str());
   
   
   page += view.render ("notes", "bb-n");
