@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ bool notes_create_acl (void * webserver_request)
 
 string notes_create (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
   
@@ -71,7 +71,7 @@ string notes_create (void * webserver_request)
   // If no Bible is passed, it takes the user's active Bible.
   string bible = request->post ["bible"];
   if (bible.empty ()) {
-    bible = access_bible_clamp (webserver_request, request->database_config_user()->getBible ());
+    bible = AccessBible::Clamp (webserver_request, request->database_config_user()->getBible ());
   }
   
   
@@ -86,11 +86,18 @@ string notes_create (void * webserver_request)
   else verse = Ipc_Focus::getVerse (webserver_request);
 
   
-  if (request->post.count ("submit")) {
+  if (request->post.count ("summary")) {
     string summary = filter_string_trim (request->post["summary"]);
-    string contents = filter_string_trim (request->post["contents"]);
-    notes_logic.createNote (bible, book, chapter, verse, summary, contents, false);
-    redirect_browser (request, notes_index_url ());
+    summary = filter_url_tag_to_plus (summary);
+    string body = filter_string_trim (request->post["body"]);
+    body = filter_url_tag_to_plus (body);
+    // Normally the new note applies to the currently selected Bible.
+    if (config_logic_indonesian_cloud_free ()) {
+      // Indonesian free Cloud: A new note applies to all Bibles.
+      // https://github.com/bibledit/cloud/issues/519
+      bible.clear ();
+    }
+    notes_logic.createNote (bible, book, chapter, verse, summary, body, false);
     return "";
   }
 
@@ -132,15 +139,16 @@ string notes_create (void * webserver_request)
     string stylesheet = styles_logic_standard_sheet ();
     Filter_Text filter_text = Filter_Text (bible);
     filter_text.text_text = new Text_Text ();
-    filter_text.addUsfmCode (verse_usfm);
+    filter_text.add_usfm_code (verse_usfm);
     filter_text.run (stylesheet);
     versetext = filter_text.text_text->get ();
     view.set_variable ("versetext", versetext);
   }
                                                                                                       
   
+  // page += view.render ("notes", "create");
   page += view.render ("notes", "create");
-  
+
   page += Assets_Page::footer ();
   
   return page;
