@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,14 +17,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_NOTES_LOGIC_H
-#define INCLUDED_NOTES_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/passage.h>
 
-
 class Notes_Logic
 {
 public:
@@ -64,8 +61,4 @@ private:
   void emailUsers (int identifier, const string& label, string bible, const vector <string> & users, bool postpone);
 };
 
-
 void notes_logic_maintain_note_assignees (bool force);
-
-
-#endif
