@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ bool notes_status_1_acl (void * webserver_request)
 
 string notes_status_1 (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
   
@@ -74,12 +74,12 @@ string notes_status_1 (void * webserver_request)
   }
   
   
-  string statusblock;
+  stringstream statusblock;
   vector <Database_Notes_Text> statuses = database_notes.get_possible_statuses ();
   for (auto & status : statuses) {
-    statusblock.append ("<li><a href=\"status-1?id=" + convert_to_string (id) + "&status=" + status.raw + "\">" + status.localized + "</a></li>\n");
+    statusblock << "<li><a href=" << quoted ("status-1?id=" + convert_to_string (id) + "&status=" + status.raw) << ">" << status.localized + "</a></li>" << endl;
   }
-  view.set_variable ("statusblock", statusblock);
+  view.set_variable ("statusblock", statusblock.str());
   
   
   view.set_variable ("success", success);
