@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_PUBLIC_NOTES_H
-#define INCLUDED_PUBLIC_NOTES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 string public_notes_url ();
 bool public_notes_acl (void * webserver_request);
 string public_notes (void * webserver_request);
-
-
-#endif
