@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ bool resource_bible2resource_acl (void * webserver_request)
 
 string resource_bible2resource (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_UsfmResources database_usfmresources = Database_UsfmResources ();
 
   
@@ -77,7 +77,7 @@ string resource_bible2resource (void * webserver_request)
   
   
   if (request->query.count ("convert")) {
-    if (access_bible_write (request, bible)) {
+    if (AccessBible::Write (request, bible)) {
       tasks_logic_queue (CONVERTBIBLE2RESOURCE, {bible});
       redirect_browser (request, journal_index_url ());
       return "";
