@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 #include <journal/index.h>
 #include <menu/logic.h>
 #include <resource/cache.h>
+#include <client/logic.h>
 
 
 string resource_download_url ()
@@ -51,7 +52,7 @@ bool resource_download_acl (void * webserver_request)
 
 string resource_download (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_UsfmResources database_usfmresources;
   
   
@@ -101,7 +102,9 @@ string resource_download (void * webserver_request)
   
   
   if (resource_logic_can_cache (name)) {
-    view.enable_zone ("installable");
+    bool cache = !in_array(name, client_logic_no_cache_resources_get ());
+    if (cache) view.enable_zone ("installable");
+    else view.enable_zone("nocache");
   } else {
     view.enable_zone ("embedded");
   }
