@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -43,15 +43,14 @@ string search_all_url ()
 bool search_all_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) return true;
-  bool read, write;
-  access_a_bible (webserver_request, read, write);
+  auto [ read, write ] =  AccessBible::Any (webserver_request);
   return read;
 }
 
 
 string search_all (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   
   string page;
@@ -88,14 +87,14 @@ string search_all (void * webserver_request)
   string siteUrl = config_logic_site_url (webserver_request);
 
   
-  vector <string> bibles = access_bible_bibles (request);
+  vector <string> bibles = AccessBible::Bibles (request);
 
 
   // Search the notes.
   vector <int> identifiers = database_notes.search_notes (queryString, bibles);
   
   
-  int noteCount = identifiers.size();
+  size_t noteCount = identifiers.size();
   view.set_variable ("noteCount", convert_to_string (noteCount));
   
   
@@ -146,7 +145,7 @@ string search_all (void * webserver_request)
   vector <Passage> passages = search_logic_search_text (queryString, bibles);
   
   
-  int textCount = passages.size ();
+  size_t textCount = passages.size ();
   view.set_variable ("textCount", convert_to_string (textCount));
   
   
