@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,13 +30,13 @@
 
 string search_logic_index_folder ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "search");
+  return filter_url_create_root_path ({database_logic_databases (), "search"});
 }
 
 
 string search_logic_bible_fragment (string bible)
 {
-  return filter_url_create_path (search_logic_index_folder (), bible + "_");
+  return filter_url_create_path ({search_logic_index_folder (), bible + "_"});
 }
 
 
@@ -109,7 +109,7 @@ void search_logic_index_chapter (string bible, int book, int chapter)
     Filter_Text filter_text = Filter_Text (bible);
     filter_text.text_text = new Text_Text ();
     filter_text.initializeHeadingsAndTextPerVerse (true);
-    filter_text.addUsfmCode (raw_usfm);
+    filter_text.add_usfm_code (raw_usfm);
     filter_text.run (stylesheet);
 
     string raw_plain;
@@ -442,7 +442,7 @@ void search_logic_delete_bible (string bible)
   vector <string> files = filter_url_scandir (search_logic_index_folder ());
   for (auto & file : files) {
     if (file.find (fragment) == 0) {
-      string path = filter_url_create_path (search_logic_index_folder (), file);
+      string path = filter_url_create_path ({search_logic_index_folder (), file});
       filter_url_unlink (path);
     }
   }
@@ -456,7 +456,7 @@ void search_logic_delete_book (string bible, int book)
   vector <string> files = filter_url_scandir (search_logic_index_folder ());
   for (auto & file : files) {
     if (file.find (fragment) == 0) {
-      string path = filter_url_create_path (search_logic_index_folder (), file);
+      string path = filter_url_create_path ({search_logic_index_folder (), file});
       filter_url_unlink (path);
     }
   }
@@ -470,7 +470,7 @@ void search_logic_delete_chapter (string bible, int book, int chapter)
   vector <string> files = filter_url_scandir (search_logic_index_folder ());
   for (auto & file : files) {
     if (file.find (fragment) == 0) {
-      string path = filter_url_create_path (search_logic_index_folder (), file);
+      string path = filter_url_create_path ({search_logic_index_folder (), file});
       filter_url_unlink (path);
     }
   }
@@ -510,9 +510,9 @@ void search_logic_copy_bible (string original, string destination)
   vector <string> files = filter_url_scandir (search_logic_index_folder ());
   for (auto & file : files) {
     if (file.find (original_fragment) == 0) {
-      string original_path = filter_url_create_path (search_logic_index_folder (), file);
+      string original_path = filter_url_create_path ({search_logic_index_folder (), file});
       string destination_file = destination_fragment + file.substr (original_fragment.length ());
-      string destination_path = filter_url_create_path (search_logic_index_folder (), destination_file);
+      string destination_path = filter_url_create_path ({search_logic_index_folder (), destination_file});
       filter_url_file_cp (original_path, destination_path);
     }
   }
@@ -526,7 +526,7 @@ string search_logic_plain_replace_verse_text (string usfm)
   Filter_Text filter_text = Filter_Text ("");
   filter_text.text_text = new Text_Text ();
   filter_text.initializeHeadingsAndTextPerVerse (true);
-  filter_text.addUsfmCode (usfm);
+  filter_text.add_usfm_code (usfm);
   filter_text.run (styles_logic_standard_sheet ());
   
   // The resulting plain text.
