@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,14 +17,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_SEARCH_REBIBLES_H
-#define INCLUDED_SEARCH_REBIBLES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 void search_reindex_bibles (bool force);
-
-
-#endif
