@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,17 +17,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_SESSION_LOGIN_H
-#define INCLUDED_SESSION_LOGIN_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 const char * session_login_url ();
 bool session_login_acl (void * webserver_request);
 string session_login (void * webserver_request);
 string session_login_display_header (void * webserver_request);
-
-
-#endif
