@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ bool session_password_acl (void * webserver_request)
 
 string session_password (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   string page;
 
@@ -78,7 +78,7 @@ string session_password (void * webserver_request)
     }
     if (form_is_valid) {
       // Generate and store a new password.
-      string generated_password = md5 (convert_to_string (filter_string_rand (0, 1000000)));
+      string generated_password = md5 (convert_to_string (filter_string_rand (0, 1'000'000)));
       generated_password = generated_password.substr (0, 15);
       string username = database_users.getEmailToUser (email);
       database_users.set_password (username, generated_password);
@@ -98,7 +98,7 @@ string session_password (void * webserver_request)
     }
   }
   
-  view.set_variable ("mailer", email_setup_information ());
+  view.set_variable ("mailer", email_setup_information (true, false));
 
   page += view.render ("session", "password");
 
