@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -97,7 +97,7 @@ void sources_morphhb_parse ()
     string file = "sources/morphhb/" + books[bk] + ".xml";
     cout << file << endl;
 
-    int book = bk + 1;
+    int book = static_cast<int>(bk + 1);
 
     xml_document document;
     document.load_file (file.c_str());
