@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,17 +17,13 @@
  */
 
 
-#ifndef INCLUDED_STYLES_SHEETS_H
-#define INCLUDED_STYLES_SHEETS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 void styles_sheets_create_all ();
 void styles_sheets_create_all_run ();
 
-
 class Styles_Sheets
 {
 public:
@@ -36,6 +32,3 @@ public:
   string get_location (string sheet, bool editor);
 private:
 };
-
-
-#endif
