@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ string sync_files_url ()
 
 string sync_files (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Sync_Logic sync_logic = Sync_Logic (webserver_request);
 
   if (!sync_logic.security_okay ()) {
@@ -95,7 +95,7 @@ string sync_files (void * webserver_request)
     // This triggers the correct mime type.
     request->get = "file.download";
     // Return the file's contents.
-    string path = filter_url_create_root_path (directory, file);
+    string path = filter_url_create_root_path ({directory, file});
     return filter_url_file_get_contents (path);
   }
   
