@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,9 +17,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_SYNC_LOGIC_H
-#define INCLUDED_SYNC_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/passage.h>
@@ -144,7 +142,3 @@ private:
   void * webserver_request;
 };
 
-
-
-
-#endif
