@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,15 +17,9 @@
  */
 
 
-#ifndef INCLUDED_VERSIFICATION_LOGIC
-#define INCLUDED_VERSIFICATION_LOGIC
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 vector <string> versification_logic_names ();
 string versification_logic_data (string name);
-
-
-#endif
