@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,18 +17,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_WEBSERVER_HTTP_H
-#define INCLUDED_WEBSERVER_HTTP_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 bool http_parse_header (string header, void * webserver_request);
 void http_parse_post (string content, void * webserver_request);
 void http_assemble_response (void * webserver_request);
 void http_stream_file (void * webserver_request, bool enable_cache);
 string http_parse_host (const string & line);
-
-
-#endif
