@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <locale/translate.h>
 #include <database/config/general.h>
 #include <database/notes.h>
+#include <database/cache.h>
 #include <workspace/logic.h>
 #include <menu/logic.h>
 #include <ipc/focus.h>
@@ -47,10 +48,9 @@ bool workspace_index_acl (void * webserver_request)
 
 string workspace_index (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   vector <string> workspaces = workspace_get_names (request);
 
-  
   // Set the requested workspace as the active one.
   if (request->query.count ("bench")) {
     unsigned int bench = convert_to_int (request->query ["bench"]);
@@ -90,7 +90,7 @@ string workspace_index (void * webserver_request)
     vector <Passage> passages = database_notes.get_passages (noteid);
     if (!passages.empty ()) {
       Ipc_Focus::set (webserver_request, passages[0].book, passages[0].chapter, convert_to_int (passages[0].verse));
-      Navigation_Passage::recordHistory (webserver_request, passages[0].book, passages[0].chapter, convert_to_int (passages[0].verse));
+      Navigation_Passage::record_history (webserver_request, passages[0].book, passages[0].chapter, convert_to_int (passages[0].verse));
     }
   }
   
@@ -104,11 +104,13 @@ string workspace_index (void * webserver_request)
 
   
   map <int, string> urls = workspace_get_urls (request, true);
-  workspace_add_bible_readonly (urls);
   map <int, string> widths = workspace_get_widths (request);
+  // The Bible editor number, starting from 1, going up.
+  map <int, int> editor_numbers = workspace_add_bible_editor_number (urls);
   for (unsigned int key = 0; key < 15; key++) {
     string url = urls [key];
     string width = widths [key];
+    int editor_number = editor_numbers [key];
     int row = round (key / 5) + 1;
     int column = key % 5 + 1;
     string variable = "url" + convert_to_string (row) + convert_to_string (column);
@@ -116,6 +118,8 @@ string workspace_index (void * webserver_request)
     variable = "width" + convert_to_string (row) + convert_to_string (column);
     view.set_variable (variable, width);
     if (convert_to_int (width) > 0) view.enable_zone (variable);
+    variable = "editorno" + convert_to_string (row) + convert_to_string (column);
+    view.set_variable (variable, convert_to_string (editor_number));
   }
   
   
